#ifndef LINKRBRAIN2019__SRC__GENERATORS__COLORNAME_HPP
#define LINKRBRAIN2019__SRC__GENERATORS__COLORNAME_HPP


#include <vector>
#include <string>

#include "Types/Color.hpp"


namespace Generators {


    class ColorName {
    public:

        static const std::vector<std::pair<Types::Color, std::string>> english_names;

        static const std::string get_english_name(const Types::Color& color) {
            float closest_distance = 100.f;
            std::string closest_name;
            for (const auto& [named_color, name] : english_names) {
                const float distance = named_color.compute_distance(color);
                if (distance < closest_distance) {
                    closest_distance = distance;
                    closest_name = name;
                }
            }
            return closest_name;
        }

    };

    // TODO: consider using this: http://www.ralcolor.com/ with this: http://www.pats.ch/formulaire/unites/unites11.aspx
    const std::vector<std::pair<Types::Color, std::string>> ColorName::english_names = {
        {{0   / 255.f, 72  / 255.f, 186 / 255.f}, "absolute zero"},
        {{176 / 255.f, 191 / 255.f, 26  / 255.f}, "acid green"},
        {{124 / 255.f, 185 / 255.f, 232 / 255.f}, "aero"},
        {{201 / 255.f, 255 / 255.f, 229 / 255.f}, "aero blue"},
        {{178 / 255.f, 132 / 255.f, 190 / 255.f}, "african violet"},
        {{114 / 255.f, 160 / 255.f, 193 / 255.f}, "air superiority blue"},
        {{242 / 255.f, 240 / 255.f, 230 / 255.f}, "alabaster"},
        {{240 / 255.f, 248 / 255.f, 255 / 255.f}, "alice blue"},
        {{227 / 255.f, 38  / 255.f, 54  / 255.f}, "alizarin"},
        {{196 / 255.f, 98  / 255.f, 16  / 255.f}, "alloy orange"},
        {{239 / 255.f, 222 / 255.f, 205 / 255.f}, "almond"},
        {{229 / 255.f, 43  / 255.f, 80  / 255.f}, "amaranth"},
        {{159 / 255.f, 43  / 255.f, 104 / 255.f}, "amaranth deep purple"},
        {{241 / 255.f, 156 / 255.f, 187 / 255.f}, "amaranth pink"},
        {{171 / 255.f, 39  / 255.f, 79  / 255.f}, "amaranth purple"},
        {{211 / 255.f, 33  / 255.f, 45  / 255.f}, "amaranth red"},
        {{59  / 255.f, 122 / 255.f, 87  / 255.f}, "amazon"},
        {{255 / 255.f, 191 / 255.f, 0   / 255.f}, "amber"},
        {{153 / 255.f, 102 / 255.f, 204 / 255.f}, "amethyst"},
        {{164 / 255.f, 198 / 255.f, 57  / 255.f}, "android green"},
        {{205 / 255.f, 149 / 255.f, 117 / 255.f}, "antique brass"},
        {{102 / 255.f, 93  / 255.f, 30  / 255.f}, "antique bronze"},
        {{145 / 255.f, 92  / 255.f, 131 / 255.f}, "antique fuchsia"},
        {{132 / 255.f, 27  / 255.f, 45  / 255.f}, "antique ruby"},
        {{250 / 255.f, 235 / 255.f, 215 / 255.f}, "antique white"},
        {{0   / 255.f, 128 / 255.f, 0   / 255.f}, "ao"},
        {{141 / 255.f, 182 / 255.f, 0   / 255.f}, "apple green"},
        {{251 / 255.f, 206 / 255.f, 177 / 255.f}, "apricot"},
        {{0   / 255.f, 255 / 255.f, 255 / 255.f}, "aqua"},
        {{127 / 255.f, 255 / 255.f, 212 / 255.f}, "aquamarine"},
        {{208 / 255.f, 255 / 255.f, 20  / 255.f}, "arctic lime"},
        {{75  / 255.f, 83  / 255.f, 32  / 255.f}, "army green"},
        {{143 / 255.f, 151 / 255.f, 121 / 255.f}, "artichoke"},
        {{233 / 255.f, 214 / 255.f, 107 / 255.f}, "arylide yellow"},
        {{178 / 255.f, 190 / 255.f, 181 / 255.f}, "ash grey"},
        {{135 / 255.f, 169 / 255.f, 107 / 255.f}, "asparagus"},
        {{255 / 255.f, 153 / 255.f, 102 / 255.f}, "atomic tangerine"},
        {{165 / 255.f, 42  / 255.f, 42  / 255.f}, "auburn"},
        {{253 / 255.f, 238 / 255.f, 0   / 255.f}, "aureolin"},
        {{86  / 255.f, 130 / 255.f, 3   / 255.f}, "avocado"},
        {{0   / 255.f, 127 / 255.f, 255 / 255.f}, "azure"},
        {{137 / 255.f, 207 / 255.f, 240 / 255.f}, "baby blue"},
        {{161 / 255.f, 202 / 255.f, 241 / 255.f}, "baby blue eyes"},
        {{244 / 255.f, 194 / 255.f, 194 / 255.f}, "baby pink"},
        {{254 / 255.f, 254 / 255.f, 250 / 255.f}, "baby powder"},
        {{255 / 255.f, 145 / 255.f, 175 / 255.f}, "baker-miller pink"},
        {{250 / 255.f, 231 / 255.f, 181 / 255.f}, "banana mania"},
        {{255 / 255.f, 225 / 255.f, 53  / 255.f}, "banana yellow"},
        {{224 / 255.f, 33  / 255.f, 138 / 255.f}, "barbie pink"},
        {{124 / 255.f, 10  / 255.f, 2   / 255.f}, "barn red"},
        {{132 / 255.f, 132 / 255.f, 130 / 255.f}, "battleship grey"},
        {{188 / 255.f, 212 / 255.f, 230 / 255.f}, "beau blue"},
        {{159 / 255.f, 129 / 255.f, 112 / 255.f}, "beaver"},
        {{245 / 255.f, 245 / 255.f, 220 / 255.f}, "beige"},
        {{46  / 255.f, 88  / 255.f, 149 / 255.f}, "b'dazzled blue"},
        {{156 / 255.f, 37  / 255.f, 66  / 255.f}, "big dip o’ruby"},
        {{232 / 255.f, 142 / 255.f, 90  / 255.f}, "big foot feet"},
        {{255 / 255.f, 228 / 255.f, 196 / 255.f}, "bisque"},
        {{61  / 255.f, 43  / 255.f, 31  / 255.f}, "bistre"},
        {{150 / 255.f, 113 / 255.f, 23  / 255.f}, "bistre brown"},
        {{202 / 255.f, 224 / 255.f, 13  / 255.f}, "bitter lemon"},
        {{254 / 255.f, 111 / 255.f, 94  / 255.f}, "bittersweet"},
        {{191 / 255.f, 79  / 255.f, 81  / 255.f}, "bittersweet shimmer"},
        {{0   / 255.f, 0   / 255.f, 0   / 255.f}, "black"},
        {{61  / 255.f, 12  / 255.f, 2   / 255.f}, "black bean"},
        {{84  / 255.f, 98  / 255.f, 111 / 255.f}, "black coral"},
        {{37  / 255.f, 53  / 255.f, 41  / 255.f}, "black leather jacket"},
        {{59  / 255.f, 60  / 255.f, 54  / 255.f}, "black olive"},
        {{191 / 255.f, 175 / 255.f, 178 / 255.f}, "black shadows"},
        {{255 / 255.f, 235 / 255.f, 205 / 255.f}, "blanched almond"},
        {{165 / 255.f, 113 / 255.f, 100 / 255.f}, "blast-off bronze"},
        {{49  / 255.f, 140 / 255.f, 231 / 255.f}, "bleu de france"},
        {{172 / 255.f, 229 / 255.f, 238 / 255.f}, "blizzard blue"},
        {{102 / 255.f, 0   / 255.f, 0   / 255.f}, "blood red"},
        {{0   / 255.f, 0   / 255.f, 255 / 255.f}, "blue"},
        {{162 / 255.f, 162 / 255.f, 208 / 255.f}, "blue bell"},
        {{102 / 255.f, 153 / 255.f, 204 / 255.f}, "blue-gray"},
        {{13  / 255.f, 152 / 255.f, 186 / 255.f}, "blue-green"},
        {{93  / 255.f, 173 / 255.f, 236 / 255.f}, "blue jeans"},
        {{18  / 255.f, 97  / 255.f, 128 / 255.f}, "blue sapphire"},
        {{138 / 255.f, 43  / 255.f, 226 / 255.f}, "blue-violet"},
        {{80  / 255.f, 114 / 255.f, 167 / 255.f}, "blue yonder"},
        {{79  / 255.f, 134 / 255.f, 247 / 255.f}, "blueberry"},
        {{222 / 255.f, 93  / 255.f, 131 / 255.f}, "blush"},
        {{121 / 255.f, 68  / 255.f, 59  / 255.f}, "bole"},
        {{227 / 255.f, 218 / 255.f, 201 / 255.f}, "bone"},
        {{221 / 255.f, 226 / 255.f, 106 / 255.f}, "booger buster"},
        {{0   / 255.f, 106 / 255.f, 78  / 255.f}, "bottle green"},
        {{203 / 255.f, 65  / 255.f, 84  / 255.f}, "brick red"},
        {{102 / 255.f, 255 / 255.f, 0   / 255.f}, "bright green"},
        {{216 / 255.f, 145 / 255.f, 239 / 255.f}, "bright lilac"},
        {{195 / 255.f, 33  / 255.f, 72  / 255.f}, "bright maroon"},
        {{25  / 255.f, 116 / 255.f, 210 / 255.f}, "bright navy blue"},
        {{255 / 255.f, 0   / 255.f, 127 / 255.f}, "bright pink"},
        {{8   / 255.f, 232 / 255.f, 222 / 255.f}, "bright turquoise"},
        {{255 / 255.f, 170 / 255.f, 29  / 255.f}, "bright yellow"},
        {{246 / 255.f, 83  / 255.f, 166 / 255.f}, "brilliant rose"},
        {{251 / 255.f, 96  / 255.f, 127 / 255.f}, "brink pink"},
        {{0   / 255.f, 66  / 255.f, 37  / 255.f}, "british racing green"},
        {{205 / 255.f, 127 / 255.f, 50  / 255.f}, "bronze"},
        {{150 / 255.f, 75  / 255.f, 0   / 255.f}, "brown"},
        {{175 / 255.f, 110 / 255.f, 77  / 255.f}, "brown sugar"},
        {{27  / 255.f, 77  / 255.f, 62  / 255.f}, "brunswick green"},
        {{123 / 255.f, 182 / 255.f, 97  / 255.f}, "bud green"},
        {{240 / 255.f, 220 / 255.f, 130 / 255.f}, "buff"},
        {{128 / 255.f, 0   / 255.f, 32  / 255.f}, "burgundy"},
        {{222 / 255.f, 184 / 255.f, 135 / 255.f}, "burlywood"},
        {{161 / 255.f, 122 / 255.f, 116 / 255.f}, "burnished brown"},
        {{204 / 255.f, 85  / 255.f, 0   / 255.f}, "burnt orange"},
        {{233 / 255.f, 116 / 255.f, 81  / 255.f}, "burnt sienna"},
        {{138 / 255.f, 51  / 255.f, 36  / 255.f}, "burnt umber"},
        {{189 / 255.f, 51  / 255.f, 164 / 255.f}, "byzantine"},
        {{112 / 255.f, 41  / 255.f, 99  / 255.f}, "byzantium"},
        {{83  / 255.f, 104 / 255.f, 114 / 255.f}, "cadet"},
        {{95  / 255.f, 158 / 255.f, 160 / 255.f}, "cadet blue"},
        {{145 / 255.f, 163 / 255.f, 176 / 255.f}, "cadet grey"},
        {{0   / 255.f, 107 / 255.f, 60  / 255.f}, "cadmium green"},
        {{237 / 255.f, 135 / 255.f, 45  / 255.f}, "cadmium orange"},
        {{227 / 255.f, 0   / 255.f, 34  / 255.f}, "cadmium red"},
        {{255 / 255.f, 246 / 255.f, 0   / 255.f}, "cadmium yellow"},
        {{166 / 255.f, 123 / 255.f, 91  / 255.f}, "café au lait"},
        {{75  / 255.f, 54  / 255.f, 33  / 255.f}, "café noir"},
        {{66  / 255.f, 236 / 255.f, 255 / 255.f}, "calypso"},
        {{163 / 255.f, 193 / 255.f, 173 / 255.f}, "cambridge blue"},
        {{193 / 255.f, 154 / 255.f, 107 / 255.f}, "camel"},
        {{239 / 255.f, 187 / 255.f, 204 / 255.f}, "cameo pink"},
        {{255 / 255.f, 255 / 255.f, 153 / 255.f}, "canary yellow"},
        {{255 / 255.f, 8   / 255.f, 0   / 255.f}, "candy apple red"},
        {{228 / 255.f, 113 / 255.f, 122 / 255.f}, "candy pink"},
        {{89  / 255.f, 39  / 255.f, 32  / 255.f}, "caput mortuum"},
        {{196 / 255.f, 30  / 255.f, 58  / 255.f}, "cardinal"},
        {{0   / 255.f, 204 / 255.f, 153 / 255.f}, "caribbean green"},
        {{150 / 255.f, 0   / 255.f, 24  / 255.f}, "carmine"},
        {{255 / 255.f, 166 / 255.f, 201 / 255.f}, "carnation pink"},
        {{179 / 255.f, 27  / 255.f, 27  / 255.f}, "carnelian"},
        {{86  / 255.f, 160 / 255.f, 211 / 255.f}, "carolina blue"},
        {{237 / 255.f, 145 / 255.f, 33  / 255.f}, "carrot orange"},
        {{0   / 255.f, 86  / 255.f, 63  / 255.f}, "castleton green"},
        {{112 / 255.f, 54  / 255.f, 66  / 255.f}, "catawba"},
        {{202 / 255.f, 52  / 255.f, 53  / 255.f}, "cedar chest"},
        {{172 / 255.f, 225 / 255.f, 175 / 255.f}, "celadon"},
        {{47  / 255.f, 132 / 255.f, 124 / 255.f}, "celadon green"},
        {{178 / 255.f, 255 / 255.f, 255 / 255.f}, "celeste"},
        {{222 / 255.f, 49  / 255.f, 99  / 255.f}, "cerise"},
        {{0   / 255.f, 123 / 255.f, 167 / 255.f}, "cerulean"},
        {{42  / 255.f, 82  / 255.f, 190 / 255.f}, "cerulean blue"},
        {{109 / 255.f, 155 / 255.f, 195 / 255.f}, "cerulean frost"},
        {{247 / 255.f, 231 / 255.f, 206 / 255.f}, "champagne"},
        {{241 / 255.f, 221 / 255.f, 207 / 255.f}, "champagne pink"},
        {{54  / 255.f, 69  / 255.f, 79  / 255.f}, "charcoal"},
        {{35  / 255.f, 43  / 255.f, 43  / 255.f}, "charleston green"},
        {{230 / 255.f, 143 / 255.f, 172 / 255.f}, "charm pink"},
        {{223 / 255.f, 255 / 255.f, 0   / 255.f}, "chartreuse"},
        {{255 / 255.f, 183 / 255.f, 197 / 255.f}, "cherry blossom pink"},
        {{149 / 255.f, 69  / 255.f, 53  / 255.f}, "chestnut"},
        {{222 / 255.f, 111 / 255.f, 161 / 255.f}, "china pink"},
        {{168 / 255.f, 81  / 255.f, 110 / 255.f}, "china rose"},
        {{170 / 255.f, 56  / 255.f, 30  / 255.f}, "chinese red"},
        {{133 / 255.f, 96  / 255.f, 136 / 255.f}, "chinese violet"},
        {{123 / 255.f, 63  / 255.f, 0   / 255.f}, "chocolate"},
        {{152 / 255.f, 129 / 255.f, 123 / 255.f}, "cinereous"},
        {{205 / 255.f, 96  / 255.f, 126 / 255.f}, "cinnamon satin"},
        {{228 / 255.f, 208 / 255.f, 10  / 255.f}, "citrine"},
        {{158 / 255.f, 169 / 255.f, 31  / 255.f}, "citron"},
        {{127 / 255.f, 23  / 255.f, 52  / 255.f}, "claret"},
        {{0   / 255.f, 71  / 255.f, 171 / 255.f}, "cobalt blue"},
        {{210 / 255.f, 105 / 255.f, 30  / 255.f}, "cocoa brown"},
        {{150 / 255.f, 90  / 255.f, 62  / 255.f}, "coconut"},
        {{111 / 255.f, 78  / 255.f, 55  / 255.f}, "coffee"},
        {{196 / 255.f, 216 / 255.f, 226 / 255.f}, "columbia blue"},
        {{248 / 255.f, 131 / 255.f, 121 / 255.f}, "congo pink"},
        {{140 / 255.f, 146 / 255.f, 172 / 255.f}, "cool grey"},
        {{184 / 255.f, 115 / 255.f, 51  / 255.f}, "copper"},
        {{173 / 255.f, 111 / 255.f, 105 / 255.f}, "copper penny"},
        {{203 / 255.f, 109 / 255.f, 81  / 255.f}, "copper red"},
        {{153 / 255.f, 102 / 255.f, 102 / 255.f}, "copper rose"},
        {{255 / 255.f, 56  / 255.f, 0   / 255.f}, "coquelicot"},
        {{255 / 255.f, 127 / 255.f, 80  / 255.f}, "coral"},
        {{248 / 255.f, 131 / 255.f, 121 / 255.f}, "coral pink"},
        {{137 / 255.f, 63  / 255.f, 69  / 255.f}, "cordovan"},
        {{179 / 255.f, 27  / 255.f, 27  / 255.f}, "cornell red"},
        {{1   / 255.f, 159 / 255.f, 222 / 255.f}, "cornflower blue"},
        {{255 / 255.f, 248 / 255.f, 220 / 255.f}, "cornsilk"},
        {{46  / 255.f, 45  / 255.f, 136 / 255.f}, "cosmic cobalt"},
        {{255 / 255.f, 248 / 255.f, 231 / 255.f}, "cosmic latte"},
        {{129 / 255.f, 97  / 255.f, 60  / 255.f}, "coyote brown"},
        {{255 / 255.f, 188 / 255.f, 217 / 255.f}, "cotton candy"},
        {{255 / 255.f, 253 / 255.f, 208 / 255.f}, "cream"},
        {{220 / 255.f, 20  / 255.f, 60  / 255.f}, "crimson"},
        {{245 / 255.f, 245 / 255.f, 245 / 255.f}, "cultured"},
        {{0   / 255.f, 255 / 255.f, 255 / 255.f}, "cyan"},
        {{88  / 255.f, 66  / 255.f, 124 / 255.f}, "cyber grape"},
        {{255 / 255.f, 211 / 255.f, 0   / 255.f}, "cyber yellow"},
        {{245 / 255.f, 111 / 255.f, 161 / 255.f}, "cyclamen"},
        {{221 / 255.f, 247 / 255.f, 25  / 255.f}, "dandelion"},
        {{0   / 255.f, 0   / 255.f, 139 / 255.f}, "dark blue"},
        {{102 / 255.f, 102 / 255.f, 153 / 255.f}, "dark blue-gray"},
        {{101 / 255.f, 67  / 255.f, 33  / 255.f}, "dark brown"},
        {{93  / 255.f, 57  / 255.f, 84  / 255.f}, "dark byzantium"},
        {{0   / 255.f, 139 / 255.f, 139 / 255.f}, "dark cyan"},
        {{83  / 255.f, 104 / 255.f, 120 / 255.f}, "dark electric blue"},
        {{160 / 255.f, 9   / 255.f, 85  / 255.f}, "dark fuchsia"},
        {{184 / 255.f, 134 / 255.f, 11  / 255.f}, "dark goldenrod"},
        {{169 / 255.f, 169 / 255.f, 169 / 255.f}, "dark gray"},
        {{1   / 255.f, 50  / 255.f, 32  / 255.f}, "dark green"},
        {{0   / 255.f, 100 / 255.f, 0   / 255.f}, "dark green"},
        {{26  / 255.f, 36  / 255.f, 33  / 255.f}, "dark jungle green"},
        {{189 / 255.f, 183 / 255.f, 107 / 255.f}, "dark khaki"},
        {{72  / 255.f, 60  / 255.f, 50  / 255.f}, "dark lava"},
        {{83  / 255.f, 75  / 255.f, 79  / 255.f}, "dark liver"},
        {{139 / 255.f, 0   / 255.f, 139 / 255.f}, "dark magenta"},
        {{0   / 255.f, 51  / 255.f, 102 / 255.f}, "dark midnight blue"},
        {{74  / 255.f, 93  / 255.f, 35  / 255.f}, "dark moss green"},
        {{85  / 255.f, 107 / 255.f, 47  / 255.f}, "dark olive green"},
        {{255 / 255.f, 140 / 255.f, 0   / 255.f}, "dark orange"},
        {{153 / 255.f, 50  / 255.f, 204 / 255.f}, "dark orchid"},
        {{3   / 255.f, 192 / 255.f, 60  / 255.f}, "dark pastel green"},
        {{48  / 255.f, 25  / 255.f, 52  / 255.f}, "dark purple"},
        {{135 / 255.f, 38  / 255.f, 87  / 255.f}, "dark raspberry"},
        {{139 / 255.f, 0   / 255.f, 0   / 255.f}, "dark red"},
        {{233 / 255.f, 150 / 255.f, 122 / 255.f}, "dark salmon"},
        {{143 / 255.f, 188 / 255.f, 143 / 255.f}, "dark sea green"},
        {{60  / 255.f, 20  / 255.f, 20  / 255.f}, "dark sienna"},
        {{140 / 255.f, 190 / 255.f, 214 / 255.f}, "dark sky blue"},
        {{72  / 255.f, 61  / 255.f, 139 / 255.f}, "dark slate blue"},
        {{47  / 255.f, 79  / 255.f, 79  / 255.f}, "dark slate gray"},
        {{23  / 255.f, 114 / 255.f, 69  / 255.f}, "dark spring green"},
        {{145 / 255.f, 129 / 255.f, 81  / 255.f}, "dark tan"},
        {{0   / 255.f, 206 / 255.f, 209 / 255.f}, "dark turquoise"},
        {{209 / 255.f, 190 / 255.f, 168 / 255.f}, "dark vanilla"},
        {{148 / 255.f, 0   / 255.f, 211 / 255.f}, "dark violet"},
        {{0   / 255.f, 112 / 255.f, 60  / 255.f}, "dartmouth green"},
        {{85  / 255.f, 85  / 255.f, 85  / 255.f}, "davy's grey"},
        {{218 / 255.f, 50  / 255.f, 135 / 255.f}, "deep cerise"},
        {{250 / 255.f, 214 / 255.f, 165 / 255.f}, "deep champagne"},
        {{185 / 255.f, 78  / 255.f, 72  / 255.f}, "deep chestnut"},
        {{193 / 255.f, 84  / 255.f, 193 / 255.f}, "deep fuchsia"},
        {{0   / 255.f, 75  / 255.f, 73  / 255.f}, "deep jungle green"},
        {{245 / 255.f, 199 / 255.f, 26  / 255.f}, "deep lemon"},
        {{212 / 255.f, 115 / 255.f, 212 / 255.f}, "deep mauve"},
        {{255 / 255.f, 20  / 255.f, 147 / 255.f}, "deep pink"},
        {{0   / 255.f, 191 / 255.f, 255 / 255.f}, "deep sky blue"},
        {{74  / 255.f, 100 / 255.f, 108 / 255.f}, "deep space sparkle"},
        {{126 / 255.f, 94  / 255.f, 96  / 255.f}, "deep taupe"},
        {{21  / 255.f, 96  / 255.f, 189 / 255.f}, "denim"},
        {{34  / 255.f, 67  / 255.f, 182 / 255.f}, "denim blue"},
        {{193 / 255.f, 154 / 255.f, 107 / 255.f}, "desert"},
        {{237 / 255.f, 201 / 255.f, 175 / 255.f}, "desert sand"},
        {{200 / 255.f, 229 / 255.f, 235 / 255.f}, "diamond"},
        {{105 / 255.f, 105 / 255.f, 105 / 255.f}, "dim gray"},
        {{197 / 255.f, 49  / 255.f, 81  / 255.f}, "dingy dungeon"},
        {{155 / 255.f, 118 / 255.f, 83  / 255.f}, "dirt"},
        {{30  / 255.f, 144 / 255.f, 255 / 255.f}, "dodger blue"},
        {{215 / 255.f, 24  / 255.f, 104 / 255.f}, "dogwood rose"},
        {{0   / 255.f, 0   / 255.f, 156 / 255.f}, "duke blue"},
        {{239 / 255.f, 223 / 255.f, 187 / 255.f}, "dutch white"},
        {{225 / 255.f, 169 / 255.f, 95  / 255.f}, "earth yellow"},
        {{85  / 255.f, 93  / 255.f, 80  / 255.f}, "ebony"},
        {{194 / 255.f, 178 / 255.f, 128 / 255.f}, "ecru"},
        {{27  / 255.f, 27  / 255.f, 27  / 255.f}, "eerie black"},
        {{97  / 255.f, 64  / 255.f, 81  / 255.f}, "eggplant"},
        {{240 / 255.f, 234 / 255.f, 214 / 255.f}, "eggshell"},
        {{16  / 255.f, 52  / 255.f, 166 / 255.f}, "egyptian blue"},
        {{125 / 255.f, 249 / 255.f, 255 / 255.f}, "electric blue"},
        {{255 / 255.f, 0   / 255.f, 63  / 255.f}, "electric crimson"},
        {{111 / 255.f, 0   / 255.f, 255 / 255.f}, "electric indigo"},
        {{204 / 255.f, 255 / 255.f, 0   / 255.f}, "electric lime"},
        {{191 / 255.f, 0   / 255.f, 255 / 255.f}, "electric purple"},
        {{143 / 255.f, 0   / 255.f, 255 / 255.f}, "electric violet"},
        {{80  / 255.f, 200 / 255.f, 120 / 255.f}, "emerald"},
        {{108 / 255.f, 48  / 255.f, 130 / 255.f}, "eminence"},
        {{180 / 255.f, 131 / 255.f, 149 / 255.f}, "english lavender"},
        {{171 / 255.f, 75  / 255.f, 82  / 255.f}, "english red"},
        {{204 / 255.f, 71  / 255.f, 75  / 255.f}, "english vermillion"},
        {{86  / 255.f, 60  / 255.f, 92  / 255.f}, "english violet"},
        {{150 / 255.f, 200 / 255.f, 162 / 255.f}, "eton blue"},
        {{68  / 255.f, 215 / 255.f, 168 / 255.f}, "eucalyptus"},
        {{193 / 255.f, 154 / 255.f, 107 / 255.f}, "fallow"},
        {{128 / 255.f, 24  / 255.f, 24  / 255.f}, "falu red"},
        {{181 / 255.f, 51  / 255.f, 137 / 255.f}, "fandango"},
        {{222 / 255.f, 82  / 255.f, 133 / 255.f}, "fandango pink"},
        {{244 / 255.f, 0   / 255.f, 161 / 255.f}, "fashion fuchsia"},
        {{229 / 255.f, 170 / 255.f, 112 / 255.f}, "fawn"},
        {{77  / 255.f, 93  / 255.f, 83  / 255.f}, "feldgrau"},
        {{79  / 255.f, 121 / 255.f, 66  / 255.f}, "fern green"},
        {{108 / 255.f, 84  / 255.f, 30  / 255.f}, "field drab"},
        {{255 / 255.f, 84  / 255.f, 112 / 255.f}, "fiery rose"},
        {{178 / 255.f, 34  / 255.f, 34  / 255.f}, "firebrick"},
        {{206 / 255.f, 32  / 255.f, 41  / 255.f}, "fire engine red"},
        {{233 / 255.f, 92  / 255.f, 75  / 255.f}, "fire opal"},
        {{226 / 255.f, 88  / 255.f, 34  / 255.f}, "flame"},
        {{238 / 255.f, 220 / 255.f, 130 / 255.f}, "flax"},
        {{162 / 255.f, 0   / 255.f, 109 / 255.f}, "flirt"},
        {{255 / 255.f, 250 / 255.f, 240 / 255.f}, "floral white"},
        {{21  / 255.f, 244 / 255.f, 238 / 255.f}, "fluorescent blue"},
        {{1   / 255.f, 68  / 255.f, 33  / 255.f}, "forest green"},
        {{166 / 255.f, 123 / 255.f, 91  / 255.f}, "french beige"},
        {{133 / 255.f, 109 / 255.f, 77  / 255.f}, "french bistre"},
        {{0   / 255.f, 114 / 255.f, 187 / 255.f}, "french blue"},
        {{253 / 255.f, 63  / 255.f, 146 / 255.f}, "french fuchsia"},
        {{134 / 255.f, 96  / 255.f, 142 / 255.f}, "french lilac"},
        {{158 / 255.f, 253 / 255.f, 56  / 255.f}, "french lime"},
        {{212 / 255.f, 115 / 255.f, 212 / 255.f}, "french mauve"},
        {{253 / 255.f, 108 / 255.f, 158 / 255.f}, "french pink"},
        {{199 / 255.f, 44  / 255.f, 72  / 255.f}, "french raspberry"},
        {{246 / 255.f, 74  / 255.f, 138 / 255.f}, "french rose"},
        {{119 / 255.f, 181 / 255.f, 254 / 255.f}, "french sky blue"},
        {{136 / 255.f, 6   / 255.f, 206 / 255.f}, "french violet"},
        {{233 / 255.f, 54  / 255.f, 167 / 255.f}, "frostbite"},
        {{255 / 255.f, 0   / 255.f, 255 / 255.f}, "fuchsia"},
        {{204 / 255.f, 57  / 255.f, 123 / 255.f}, "fuchsia purple"},
        {{199 / 255.f, 67  / 255.f, 117 / 255.f}, "fuchsia rose"},
        {{228 / 255.f, 132 / 255.f, 0   / 255.f}, "fulvous"},
        {{135 / 255.f, 66  / 255.f, 31  / 255.f}, "fuzzy wuzzy"},
        {{220 / 255.f, 220 / 255.f, 220 / 255.f}, "gainsboro"},
        {{228 / 255.f, 155 / 255.f, 15  / 255.f}, "gamboge"},
        {{115 / 255.f, 54  / 255.f, 53  / 255.f}, "garnet"},
        {{0   / 255.f, 127 / 255.f, 102 / 255.f}, "generic viridian"},
        {{248 / 255.f, 248 / 255.f, 255 / 255.f}, "ghost white"},
        {{96  / 255.f, 130 / 255.f, 182 / 255.f}, "glaucous"},
        {{171 / 255.f, 146 / 255.f, 179 / 255.f}, "glossy grape"},
        {{0   / 255.f, 171 / 255.f, 102 / 255.f}, "go green"},
        {{165 / 255.f, 124 / 255.f, 0   / 255.f}, "gold"},
        {{133 / 255.f, 117 / 255.f, 78  / 255.f}, "gold fusion"},
        {{153 / 255.f, 101 / 255.f, 21  / 255.f}, "golden brown"},
        {{252 / 255.f, 194 / 255.f, 0   / 255.f}, "golden poppy"},
        {{255 / 255.f, 223 / 255.f, 0   / 255.f}, "golden yellow"},
        {{218 / 255.f, 165 / 255.f, 32  / 255.f}, "goldenrod"},
        {{103 / 255.f, 103 / 255.f, 103 / 255.f}, "granite gray"},
        {{168 / 255.f, 228 / 255.f, 160 / 255.f}, "granny smith apple"},
        {{128 / 255.f, 128 / 255.f, 128 / 255.f}, "gray"},
        {{0   / 255.f, 255 / 255.f, 0   / 255.f}, "green"},
        {{17  / 255.f, 100 / 255.f, 180 / 255.f}, "green-blue"},
        {{0   / 255.f, 153 / 255.f, 102 / 255.f}, "green-cyan"},
        {{167 / 255.f, 244 / 255.f, 50  / 255.f}, "green lizard"},
        {{110 / 255.f, 174 / 255.f, 161 / 255.f}, "green sheen"},
        {{173 / 255.f, 255 / 255.f, 47  / 255.f}, "green-yellow"},
        {{169 / 255.f, 154 / 255.f, 134 / 255.f}, "grullo"},
        {{42  / 255.f, 52  / 255.f, 57  / 255.f}, "gunmetal"},
        {{68  / 255.f, 108 / 255.f, 207 / 255.f}, "han blue"},
        {{82  / 255.f, 24  / 255.f, 250 / 255.f}, "han purple"},
        {{233 / 255.f, 214 / 255.f, 107 / 255.f}, "hansa yellow"},
        {{63  / 255.f, 255 / 255.f, 0   / 255.f}, "harlequin"},
        {{218 / 255.f, 145 / 255.f, 0   / 255.f}, "harvest gold"},
        {{255 / 255.f, 122 / 255.f, 0   / 255.f}, "heat wave"},
        {{223 / 255.f, 115 / 255.f, 255 / 255.f}, "heliotrope"},
        {{170 / 255.f, 152 / 255.f, 168 / 255.f}, "heliotrope gray"},
        {{244 / 255.f, 0   / 255.f, 161 / 255.f}, "hollywood cerise"},
        {{240 / 255.f, 255 / 255.f, 240 / 255.f}, "honeydew"},
        {{0   / 255.f, 109 / 255.f, 176 / 255.f}, "honolulu blue"},
        {{73  / 255.f, 121 / 255.f, 107 / 255.f}, "hooker's green"},
        {{255 / 255.f, 0   / 255.f, 198 / 255.f}, "hot fuchsia"},
        {{255 / 255.f, 29  / 255.f, 206 / 255.f}, "hot magenta"},
        {{255 / 255.f, 105 / 255.f, 180 / 255.f}, "hot pink"},
        {{53  / 255.f, 94  / 255.f, 59  / 255.f}, "hunter green"},
        {{113 / 255.f, 166 / 255.f, 210 / 255.f}, "iceberg"},
        {{252 / 255.f, 247 / 255.f, 94  / 255.f}, "icterine"},
        {{49  / 255.f, 145 / 255.f, 119 / 255.f}, "illuminating emerald"},
        {{237 / 255.f, 41  / 255.f, 57  / 255.f}, "imperial red"},
        {{178 / 255.f, 236 / 255.f, 93  / 255.f}, "inchworm"},
        {{76  / 255.f, 81  / 255.f, 109 / 255.f}, "independence"},
        {{19  / 255.f, 136 / 255.f, 8   / 255.f}, "india green"},
        {{205 / 255.f, 92  / 255.f, 92  / 255.f}, "indian red"},
        {{227 / 255.f, 168 / 255.f, 87  / 255.f}, "indian yellow"},
        {{75  / 255.f, 0   / 255.f, 130 / 255.f}, "indigo"},
        {{0   / 255.f, 65  / 255.f, 106 / 255.f}, "indigo dye"},
        {{192 / 255.f, 54  / 255.f, 44  / 255.f}, "international orange"},
        {{90  / 255.f, 79  / 255.f, 207 / 255.f}, "iris"},
        {{179 / 255.f, 68  / 255.f, 108 / 255.f}, "irresistible"},
        {{244 / 255.f, 240 / 255.f, 236 / 255.f}, "isabelline"},
        {{178 / 255.f, 255 / 255.f, 255 / 255.f}, "italian sky blue"},
        {{255 / 255.f, 255 / 255.f, 240 / 255.f}, "ivory"},
        {{0   / 255.f, 168 / 255.f, 107 / 255.f}, "jade"},
        {{157 / 255.f, 41  / 255.f, 51  / 255.f}, "japanese carmine"},
        {{91  / 255.f, 50  / 255.f, 86  / 255.f}, "japanese violet"},
        {{248 / 255.f, 222 / 255.f, 126 / 255.f}, "jasmine"},
        {{165 / 255.f, 11  / 255.f, 94  / 255.f}, "jazzberry jam"},
        {{52  / 255.f, 52  / 255.f, 52  / 255.f}, "jet"},
        {{244 / 255.f, 202 / 255.f, 22  / 255.f}, "jonquil"},
        {{189 / 255.f, 218 / 255.f, 87  / 255.f}, "june bud"},
        {{41  / 255.f, 171 / 255.f, 135 / 255.f}, "jungle green"},
        {{76  / 255.f, 187 / 255.f, 23  / 255.f}, "kelly green"},
        {{58  / 255.f, 176 / 255.f, 158 / 255.f}, "keppel"},
        {{232 / 255.f, 244 / 255.f, 140 / 255.f}, "key lime"},
        {{195 / 255.f, 176 / 255.f, 145 / 255.f}, "khaki"},
        {{136 / 255.f, 45  / 255.f, 23  / 255.f}, "kobe"},
        {{231 / 255.f, 159 / 255.f, 196 / 255.f}, "kobi"},
        {{107 / 255.f, 68  / 255.f, 35  / 255.f}, "kobicha"},
        {{53  / 255.f, 66  / 255.f, 48  / 255.f}, "kombu green"},
        {{79  / 255.f, 38  / 255.f, 131 / 255.f}, "ksu purple"},
        {{8   / 255.f, 120 / 255.f, 48  / 255.f}, "la salle green"},
        {{214 / 255.f, 202 / 255.f, 221 / 255.f}, "languid lavender"},
        {{224 / 255.f, 188 / 255.f, 91  / 255.f}, "lanzones"},
        {{38  / 255.f, 97  / 255.f, 156 / 255.f}, "lapis lazuli"},
        {{255 / 255.f, 255 / 255.f, 102 / 255.f}, "laser lemon"},
        {{169 / 255.f, 186 / 255.f, 157 / 255.f}, "laurel green"},
        {{207 / 255.f, 16  / 255.f, 32  / 255.f}, "lava"},
        {{181 / 255.f, 126 / 255.f, 220 / 255.f}, "lavender"},
        {{204 / 255.f, 204 / 255.f, 255 / 255.f}, "lavender blue"},
        {{255 / 255.f, 240 / 255.f, 245 / 255.f}, "lavender blush"},
        {{196 / 255.f, 195 / 255.f, 208 / 255.f}, "lavender gray"},
        {{148 / 255.f, 87  / 255.f, 235 / 255.f}, "lavender indigo"},
        {{238 / 255.f, 130 / 255.f, 238 / 255.f}, "lavender magenta"},
        {{230 / 255.f, 230 / 255.f, 250 / 255.f}, "lavender mist"},
        {{251 / 255.f, 174 / 255.f, 210 / 255.f}, "lavender pink"},
        {{150 / 255.f, 123 / 255.f, 182 / 255.f}, "lavender purple"},
        {{251 / 255.f, 160 / 255.f, 227 / 255.f}, "lavender rose"},
        {{124 / 255.f, 252 / 255.f, 0   / 255.f}, "lawn green"},
        {{255 / 255.f, 247 / 255.f, 0   / 255.f}, "lemon"},
        {{255 / 255.f, 250 / 255.f, 205 / 255.f}, "lemon chiffon"},
        {{204 / 255.f, 160 / 255.f, 29  / 255.f}, "lemon curry"},
        {{253 / 255.f, 255 / 255.f, 0   / 255.f}, "lemon glacier"},
        {{189 / 255.f, 48  / 255.f, 0   / 255.f}, "lemon iced tea"},
        {{227 / 255.f, 255 / 255.f, 0   / 255.f}, "lemon lime"},
        {{92  / 255.f, 255 / 255.f, 103 / 255.f}, "lemon lime"},
        {{246 / 255.f, 234 / 255.f, 190 / 255.f}, "lemon meringue"},
        {{255 / 255.f, 244 / 255.f, 79  / 255.f}, "lemon yellow"},
        {{186 / 255.f, 147 / 255.f, 216 / 255.f}, "lenurple"},
        {{84  / 255.f, 90  / 255.f, 167 / 255.f}, "liberty"},
        {{26  / 255.f, 17  / 255.f, 16  / 255.f}, "licorice"},
        {{253 / 255.f, 213 / 255.f, 177 / 255.f}, "light apricot"},
        {{173 / 255.f, 216 / 255.f, 230 / 255.f}, "light blue"},
        {{181 / 255.f, 101 / 255.f, 29  / 255.f}, "light brown"},
        {{230 / 255.f, 103 / 255.f, 113 / 255.f}, "light carmine pink"},
        {{85  / 255.f, 31  / 255.f, 47  / 255.f}, "light chocolate cosmos"},
        {{136 / 255.f, 172 / 255.f, 224 / 255.f}, "light cobalt blue"},
        {{240 / 255.f, 128 / 255.f, 128 / 255.f}, "light coral"},
        {{147 / 255.f, 204 / 255.f, 234 / 255.f}, "light cornflower blue"},
        {{245 / 255.f, 105 / 255.f, 145 / 255.f}, "light crimson"},
        {{224 / 255.f, 255 / 255.f, 255 / 255.f}, "light cyan"},
        {{255 / 255.f, 92  / 255.f, 205 / 255.f}, "light deep pink"},
        {{200 / 255.f, 173 / 255.f, 127 / 255.f}, "light french beige"},
        {{249 / 255.f, 132 / 255.f, 239 / 255.f}, "light fuchsia pink"},
        {{178 / 255.f, 151 / 255.f, 0   / 255.f}, "light gold"},
        {{255 / 255.f, 236 / 255.f, 139 / 255.f}, "light goldenrod"},
        {{250 / 255.f, 250 / 255.f, 210 / 255.f}, "light goldenrod yellow"},
        {{211 / 255.f, 211 / 255.f, 211 / 255.f}, "light gray"},
        {{204 / 255.f, 153 / 255.f, 204 / 255.f}, "light grayish magenta"},
        {{144 / 255.f, 238 / 255.f, 144 / 255.f}, "light green"},
        {{255 / 255.f, 179 / 255.f, 222 / 255.f}, "light hot pink"},
        {{240 / 255.f, 230 / 255.f, 140 / 255.f}, "light khaki"},
        {{211 / 255.f, 155 / 255.f, 203 / 255.f}, "light medium orchid"},
        {{173 / 255.f, 223 / 255.f, 173 / 255.f}, "light moss green"},
        {{238 / 255.f, 221 / 255.f, 98  / 255.f}, "light mustard"},
        {{254 / 255.f, 216 / 255.f, 177 / 255.f}, "light orange"},
        {{230 / 255.f, 168 / 255.f, 215 / 255.f}, "light orchid"},
        {{177 / 255.f, 156 / 255.f, 217 / 255.f}, "light pastel purple"},
        {{197 / 255.f, 203 / 255.f, 225 / 255.f}, "light periwinkle"},
        {{255 / 255.f, 182 / 255.f, 193 / 255.f}, "light pink"},
        {{255 / 255.f, 51  / 255.f, 51  / 255.f}, "light red"},
        {{233 / 255.f, 116 / 255.f, 81  / 255.f}, "light red ochre"},
        {{255 / 255.f, 160 / 255.f, 122 / 255.f}, "light salmon"},
        {{255 / 255.f, 153 / 255.f, 153 / 255.f}, "light salmon pink"},
        {{32  / 255.f, 178 / 255.f, 170 / 255.f}, "light sea green"},
        {{216 / 255.f, 216 / 255.f, 216 / 255.f}, "light silver"},
        {{135 / 255.f, 206 / 255.f, 250 / 255.f}, "light sky blue"},
        {{119 / 255.f, 136 / 255.f, 153 / 255.f}, "light slate gray"},
        {{176 / 255.f, 196 / 255.f, 222 / 255.f}, "light steel blue"},
        {{179 / 255.f, 139 / 255.f, 109 / 255.f}, "light taupe"},
        {{230 / 255.f, 143 / 255.f, 172 / 255.f}, "light thulian pink"},
        {{175 / 255.f, 228 / 255.f, 222 / 255.f}, "light turquoise"},
        {{122 / 255.f, 82  / 255.f, 153 / 255.f}, "light violet"},
        {{255 / 255.f, 255 / 255.f, 224 / 255.f}, "light yellow"},
        {{200 / 255.f, 162 / 255.f, 200 / 255.f}, "lilac"},
        {{174 / 255.f, 152 / 255.f, 170 / 255.f}, "lilac luster"},
        {{191 / 255.f, 255 / 255.f, 0   / 255.f}, "lime"},
        {{50  / 255.f, 205 / 255.f, 50  / 255.f}, "lime green"},
        {{157 / 255.f, 194 / 255.f, 9   / 255.f}, "limerick"},
        {{25  / 255.f, 89  / 255.f, 5   / 255.f}, "lincoln green"},
        {{250 / 255.f, 240 / 255.f, 230 / 255.f}, "linen"},
        {{193 / 255.f, 154 / 255.f, 107 / 255.f}, "lion"},
        {{222 / 255.f, 111 / 255.f, 161 / 255.f}, "liseran purple"},
        {{108 / 255.f, 160 / 255.f, 220 / 255.f}, "little boy blue"},
        {{248 / 255.f, 185 / 255.f, 212 / 255.f}, "little girl pink"},
        {{103 / 255.f, 76  / 255.f, 71  / 255.f}, "liver"},
        {{152 / 255.f, 116 / 255.f, 86  / 255.f}, "liver chestnut"},
        {{102 / 255.f, 153 / 255.f, 204 / 255.f}, "livid"},
        {{255 / 255.f, 254 / 255.f, 250 / 255.f}, "lotion"},
        {{123 / 255.f, 154 / 255.f, 200 / 255.f}, "lotion blue"},
        {{236 / 255.f, 207 / 255.f, 207 / 255.f}, "lotion pink"},
        {{255 / 255.f, 228 / 255.f, 205 / 255.f}, "lumber"},
        {{230 / 255.f, 32  / 255.f, 32  / 255.f}, "lust"},
        {{0   / 255.f, 28  / 255.f, 61  / 255.f}, "maastricht blue"},
        {{255 / 255.f, 189 / 255.f, 136 / 255.f}, "macaroni and cheese"},
        {{204 / 255.f, 51  / 255.f, 54  / 255.f}, "madder lake"},
        {{255 / 255.f, 0   / 255.f, 255 / 255.f}, "magenta"},
        {{192 / 255.f, 64  / 255.f, 0   / 255.f}, "mahogany"},
        {{251 / 255.f, 236 / 255.f, 93  / 255.f}, "maize"},
        {{96  / 255.f, 80  / 255.f, 220 / 255.f}, "majorelle blue"},
        {{11  / 255.f, 218 / 255.f, 81  / 255.f}, "malachite"},
        {{151 / 255.f, 154 / 255.f, 170 / 255.f}, "manatee"},
        {{243 / 255.f, 122 / 255.f, 72  / 255.f}, "mandarin"},
        {{253 / 255.f, 190 / 255.f, 2   / 255.f}, "mango"},
        {{150 / 255.f, 255 / 255.f, 0   / 255.f}, "mango green"},
        {{255 / 255.f, 130 / 255.f, 67  / 255.f}, "mango tango"},
        {{116 / 255.f, 195 / 255.f, 101 / 255.f}, "mantis"},
        {{136 / 255.f, 0   / 255.f, 133 / 255.f}, "mardi gras"},
        {{234 / 255.f, 162 / 255.f, 33  / 255.f}, "marigold"},
        {{195 / 255.f, 33  / 255.f, 72  / 255.f}, "maroon"},
        {{224 / 255.f, 176 / 255.f, 255 / 255.f}, "mauve"},
        {{145 / 255.f, 95  / 255.f, 109 / 255.f}, "mauve taupe"},
        {{239 / 255.f, 152 / 255.f, 170 / 255.f}, "mauvelous"},
        {{71  / 255.f, 171 / 255.f, 204 / 255.f}, "maximum blue"},
        {{48  / 255.f, 191 / 255.f, 191 / 255.f}, "maximum blue green"},
        {{172 / 255.f, 172 / 255.f, 230 / 255.f}, "maximum blue purple"},
        {{94  / 255.f, 140 / 255.f, 49  / 255.f}, "maximum green"},
        {{217 / 255.f, 230 / 255.f, 80  / 255.f}, "maximum green yellow"},
        {{255 / 255.f, 91  / 255.f, 0   / 255.f}, "maximum orange"},
        {{115 / 255.f, 51  / 255.f, 128 / 255.f}, "maximum purple"},
        {{246 / 255.f, 165 / 255.f, 242 / 255.f}, "maximum pink"},
        {{217 / 255.f, 33  / 255.f, 33  / 255.f}, "maximum red"},
        {{166 / 255.f, 58  / 255.f, 121 / 255.f}, "maximum red purple"},
        {{137 / 255.f, 47  / 255.f, 119 / 255.f}, "maximum violet"},
        {{250 / 255.f, 250 / 255.f, 55  / 255.f}, "maximum yellow"},
        {{242 / 255.f, 186 / 255.f, 73  / 255.f}, "maximum yellow red"},
        {{76  / 255.f, 145 / 255.f, 65  / 255.f}, "may green"},
        {{115 / 255.f, 194 / 255.f, 251 / 255.f}, "maya blue"},
        {{229 / 255.f, 183 / 255.f, 59  / 255.f}, "meat brown"},
        {{102 / 255.f, 221 / 255.f, 170 / 255.f}, "medium aquamarine"},
        {{0   / 255.f, 0   / 255.f, 205 / 255.f}, "medium blue"},
        {{226 / 255.f, 6   / 255.f, 44  / 255.f}, "medium candy apple red"},
        {{175 / 255.f, 64  / 255.f, 53  / 255.f}, "medium carmine"},
        {{243 / 255.f, 229 / 255.f, 171 / 255.f}, "medium champagne"},
        {{3   / 255.f, 80  / 255.f, 150 / 255.f}, "medium electric blue"},
        {{3   / 255.f, 121 / 255.f, 73  / 255.f}, "medium green"},
        {{28  / 255.f, 53  / 255.f, 45  / 255.f}, "medium jungle green"},
        {{221 / 255.f, 160 / 255.f, 221 / 255.f}, "medium lavender magenta"},
        {{255 / 255.f, 120 / 255.f, 2   / 255.f}, "medium orange"},
        {{186 / 255.f, 85  / 255.f, 211 / 255.f}, "medium orchid"},
        {{0   / 255.f, 103 / 255.f, 165 / 255.f}, "medium persian blue"},
        {{254 / 255.f, 110 / 255.f, 159 / 255.f}, "medium pink"},
        {{147 / 255.f, 112 / 255.f, 219 / 255.f}, "medium purple"},
        {{177 / 255.f, 3   / 255.f, 4   / 255.f}, "medium red"},
        {{187 / 255.f, 51  / 255.f, 133 / 255.f}, "medium red-violet"},
        {{170 / 255.f, 64  / 255.f, 105 / 255.f}, "medium ruby"},
        {{60  / 255.f, 179 / 255.f, 113 / 255.f}, "medium sea green"},
        {{128 / 255.f, 218 / 255.f, 235 / 255.f}, "medium sky blue"},
        {{123 / 255.f, 104 / 255.f, 238 / 255.f}, "medium slate blue"},
        {{201 / 255.f, 220 / 255.f, 135 / 255.f}, "medium spring bud"},
        {{0   / 255.f, 250 / 255.f, 154 / 255.f}, "medium spring green"},
        {{103 / 255.f, 76  / 255.f, 71  / 255.f}, "medium taupe"},
        {{72  / 255.f, 209 / 255.f, 204 / 255.f}, "medium turquoise"},
        {{121 / 255.f, 68  / 255.f, 59  / 255.f}, "medium tuscan red"},
        {{217 / 255.f, 96  / 255.f, 59  / 255.f}, "medium vermilion"},
        {{101 / 255.f, 49  / 255.f, 95  / 255.f}, "medium violet"},
        {{199 / 255.f, 21  / 255.f, 133 / 255.f}, "medium violet-red"},
        {{255 / 255.f, 227 / 255.f, 2   / 255.f}, "medium yellow"},
        {{248 / 255.f, 184 / 255.f, 120 / 255.f}, "mellow apricot"},
        {{248 / 255.f, 222 / 255.f, 126 / 255.f}, "mellow yellow"},
        {{253 / 255.f, 188 / 255.f, 180 / 255.f}, "melon"},
        {{193 / 255.f, 249 / 255.f, 162 / 255.f}, "menthol"},
        {{50  / 255.f, 82  / 255.f, 123 / 255.f}, "metallic blue"},
        {{169 / 255.f, 113 / 255.f, 66  / 255.f}, "metallic bronze"},
        {{172 / 255.f, 67  / 255.f, 19  / 255.f}, "metallic brown"},
        {{211 / 255.f, 175 / 255.f, 55  / 255.f}, "metallic gold"},
        {{41  / 255.f, 110 / 255.f, 1   / 255.f}, "metallic green"},
        {{218 / 255.f, 104 / 255.f, 15  / 255.f}, "metallic orange"},
        {{237 / 255.f, 166 / 255.f, 196 / 255.f}, "metallic pink"},
        {{166 / 255.f, 44  / 255.f, 43  / 255.f}, "metallic red"},
        {{10  / 255.f, 126 / 255.f, 140 / 255.f}, "metallic seaweed"},
        {{168 / 255.f, 169 / 255.f, 173 / 255.f}, "metallic silver"},
        {{156 / 255.f, 124 / 255.f, 56  / 255.f}, "metallic sunburst"},
        {{90  / 255.f, 10  / 255.f, 145 / 255.f}, "metallic violet"},
        {{253 / 255.f, 204 / 255.f, 13  / 255.f}, "metallic yellow"},
        {{228 / 255.f, 0   / 255.f, 124 / 255.f}, "mexican pink"},
        {{0   / 255.f, 162 / 255.f, 237 / 255.f}, "microsoft blue"},
        {{0   / 255.f, 120 / 255.f, 215 / 255.f}, "microsoft edge blue"},
        {{125 / 255.f, 183 / 255.f, 0   / 255.f}, "microsoft green"},
        {{240 / 255.f, 78  / 255.f, 31  / 255.f}, "microsoft red"},
        {{253 / 255.f, 185 / 255.f, 0   / 255.f}, "microsoft yellow"},
        {{126 / 255.f, 212 / 255.f, 230 / 255.f}, "middle blue"},
        {{141 / 255.f, 217 / 255.f, 204 / 255.f}, "middle blue green"},
        {{139 / 255.f, 114 / 255.f, 190 / 255.f}, "middle blue purple"},
        {{139 / 255.f, 134 / 255.f, 128 / 255.f}, "middle grey"},
        {{77  / 255.f, 140 / 255.f, 87  / 255.f}, "middle green"},
        {{172 / 255.f, 191 / 255.f, 96  / 255.f}, "middle green yellow"},
        {{217 / 255.f, 130 / 255.f, 181 / 255.f}, "middle purple"},
        {{229 / 255.f, 144 / 255.f, 115 / 255.f}, "middle red"},
        {{165 / 255.f, 83  / 255.f, 83  / 255.f}, "middle red purple"},
        {{255 / 255.f, 235 / 255.f, 0   / 255.f}, "middle yellow"},
        {{236 / 255.f, 177 / 255.f, 118 / 255.f}, "middle yellow red"},
        {{112 / 255.f, 38  / 255.f, 112 / 255.f}, "midnight"},
        {{25  / 255.f, 25  / 255.f, 112 / 255.f}, "midnight blue"},
        {{0   / 255.f, 70  / 255.f, 140 / 255.f}, "midnight blue"},
        {{0   / 255.f, 73  / 255.f, 83  / 255.f}, "midnight green"},
        {{255 / 255.f, 196 / 255.f, 12  / 255.f}, "mikado yellow"},
        {{253 / 255.f, 255 / 255.f, 245 / 255.f}, "milk"},
        {{132 / 255.f, 86  / 255.f, 60  / 255.f}, "milk chocolate"},
        {{255 / 255.f, 218 / 255.f, 233 / 255.f}, "mimi pink"},
        {{227 / 255.f, 249 / 255.f, 136 / 255.f}, "mindaro"},
        {{54  / 255.f, 116 / 255.f, 125 / 255.f}, "ming"},
        {{245 / 255.f, 220 / 255.f, 80  / 255.f}, "minion yellow"},
        {{62  / 255.f, 180 / 255.f, 137 / 255.f}, "mint"},
        {{245 / 255.f, 255 / 255.f, 250 / 255.f}, "mint cream"},
        {{152 / 255.f, 255 / 255.f, 152 / 255.f}, "mint green"},
        {{187 / 255.f, 180 / 255.f, 119 / 255.f}, "misty moss"},
        {{255 / 255.f, 228 / 255.f, 225 / 255.f}, "misty rose"},
        {{250 / 255.f, 235 / 255.f, 215 / 255.f}, "moccasin"},
        {{190 / 255.f, 164 / 255.f, 147 / 255.f}, "mocha"},
        {{150 / 255.f, 113 / 255.f, 23  / 255.f}, "mode beige"},
        {{58  / 255.f, 168 / 255.f, 193 / 255.f}, "moonstone"},
        {{115 / 255.f, 169 / 255.f, 194 / 255.f}, "moonstone blue"},
        {{174 / 255.f, 12  / 255.f, 0   / 255.f}, "mordant red 19"},
        {{141 / 255.f, 163 / 255.f, 153 / 255.f}, "morning blue"},
        {{138 / 255.f, 154 / 255.f, 91  / 255.f}, "moss green"},
        {{48  / 255.f, 186 / 255.f, 143 / 255.f}, "mountain meadow"},
        {{153 / 255.f, 122 / 255.f, 141 / 255.f}, "mountbatten pink"},
        {{24  / 255.f, 69  / 255.f, 59  / 255.f}, "msu green"},
        {{111 / 255.f, 83  / 255.f, 61  / 255.f}, "mud"},
        {{48  / 255.f, 96  / 255.f, 48  / 255.f}, "mughal green"},
        {{197 / 255.f, 75  / 255.f, 140 / 255.f}, "mulberry"},
        {{130 / 255.f, 142 / 255.f, 132 / 255.f}, "mummy's tomb"},
        {{255 / 255.f, 219 / 255.f, 88  / 255.f}, "mustard"},
        {{205 / 255.f, 122 / 255.f, 0   / 255.f}, "mustard brown"},
        {{110 / 255.f, 110 / 255.f, 48  / 255.f}, "mustard green"},
        {{255 / 255.f, 173 / 255.f, 1   / 255.f}, "mustard yellow"},
        {{49  / 255.f, 120 / 255.f, 115 / 255.f}, "myrtle green"},
        {{214 / 255.f, 82  / 255.f, 130 / 255.f}, "mystic"},
        {{173 / 255.f, 67  / 255.f, 121 / 255.f}, "mystic maroon"},
        {{255 / 255.f, 34  / 255.f, 0   / 255.f}, "mystic red"},
        {{246 / 255.f, 173 / 255.f, 198 / 255.f}, "nadeshiko pink"},
        {{42  / 255.f, 128 / 255.f, 0   / 255.f}, "napier green"},
        {{250 / 255.f, 218 / 255.f, 94  / 255.f}, "naples yellow"},
        {{255 / 255.f, 222 / 255.f, 173 / 255.f}, "navajo white"},
        {{0   / 255.f, 0   / 255.f, 128 / 255.f}, "navy blue"},
        {{148 / 255.f, 87  / 255.f, 235 / 255.f}, "navy purple"},
        {{27  / 255.f, 3   / 255.f, 163 / 255.f}, "neon blue"},
        {{195 / 255.f, 115 / 255.f, 42  / 255.f}, "neon brown"},
        {{255 / 255.f, 163 / 255.f, 67  / 255.f}, "neon carrot"},
        {{0   / 255.f, 254 / 255.f, 252 / 255.f}, "neon cyan"},
        {{254 / 255.f, 65  / 255.f, 100 / 255.f}, "neon fuchsia"},
        {{207 / 255.f, 170 / 255.f, 1   / 255.f}, "neon gold"},
        {{128 / 255.f, 128 / 255.f, 128 / 255.f}, "neon gray"},
        {{0   / 255.f, 132 / 255.f, 67  / 255.f}, "neon dark green"},
        {{19  / 255.f, 155 / 255.f, 66  / 255.f}, "neon green"},
        {{57  / 255.f, 255 / 255.f, 20  / 255.f}, "neon green"},
        {{254 / 255.f, 52  / 255.f, 126 / 255.f}, "neon pink"},
        {{148 / 255.f, 87  / 255.f, 235 / 255.f}, "neon purple"},
        {{255 / 255.f, 24  / 255.f, 24  / 255.f}, "neon red"},
        {{255 / 255.f, 38  / 255.f, 3   / 255.f}, "neon scarlet"},
        {{204 / 255.f, 204 / 255.f, 204 / 255.f}, "neon silver"},
        {{246 / 255.f, 137 / 255.f, 10  / 255.f}, "neon tangerine"},
        {{255 / 255.f, 247 / 255.f, 0   / 255.f}, "neon yellow"},
        {{33  / 255.f, 79  / 255.f, 198 / 255.f}, "new car"},
        {{215 / 255.f, 131 / 255.f, 127 / 255.f}, "new york pink"},
        {{114 / 255.f, 116 / 255.f, 114 / 255.f}, "nickel"},
        {{228 / 255.f, 0   / 255.f, 15  / 255.f}, "nintendo red"},
        {{164 / 255.f, 221 / 255.f, 237 / 255.f}, "non-photo blue"},
        {{233 / 255.f, 255 / 255.f, 219 / 255.f}, "nyanza"},
        {{79  / 255.f, 66  / 255.f, 181 / 255.f}, "ocean blue"},
        {{0   / 255.f, 119 / 255.f, 190 / 255.f}, "ocean boat blue"},
        {{72  / 255.f, 191 / 255.f, 145 / 255.f}, "ocean green"},
        {{204 / 255.f, 119 / 255.f, 34  / 255.f}, "ochre"},
        {{0   / 255.f, 128 / 255.f, 0   / 255.f}, "office green"},
        {{253 / 255.f, 82  / 255.f, 64  / 255.f}, "ogre odor"},
        {{67  / 255.f, 48  / 255.f, 46  / 255.f}, "old burgundy"},
        {{207 / 255.f, 181 / 255.f, 59  / 255.f}, "old gold"},
        {{86  / 255.f, 60  / 255.f, 92  / 255.f}, "old heliotrope"},
        {{253 / 255.f, 245 / 255.f, 230 / 255.f}, "old lace"},
        {{121 / 255.f, 104 / 255.f, 120 / 255.f}, "old lavender"},
        {{103 / 255.f, 49  / 255.f, 71  / 255.f}, "old mauve"},
        {{134 / 255.f, 126 / 255.f, 54  / 255.f}, "old moss green"},
        {{192 / 255.f, 128 / 255.f, 129 / 255.f}, "old rose"},
        {{132 / 255.f, 132 / 255.f, 130 / 255.f}, "old silver"},
        {{128 / 255.f, 128 / 255.f, 0   / 255.f}, "olive"},
        {{107 / 255.f, 142 / 255.f, 35  / 255.f}, "olive drab"},
        {{181 / 255.f, 179 / 255.f, 92  / 255.f}, "olive green"},
        {{154 / 255.f, 185 / 255.f, 115 / 255.f}, "olivine"},
        {{53  / 255.f, 56  / 255.f, 57  / 255.f}, "onyx"},
        {{168 / 255.f, 195 / 255.f, 188 / 255.f}, "opal"},
        {{183 / 255.f, 132 / 255.f, 167 / 255.f}, "opera mauve"},
        {{255 / 255.f, 102 / 255.f, 0   / 255.f}, "orange"},
        {{255 / 255.f, 103 / 255.f, 0   / 255.f}, "orange iced tea"},
        {{255 / 255.f, 159 / 255.f, 0   / 255.f}, "orange peel"},
        {{255 / 255.f, 104 / 255.f, 31  / 255.f}, "orange-red"},
        {{231 / 255.f, 78  / 255.f, 20  / 255.f}, "orange soda"},
        {{250 / 255.f, 91  / 255.f, 61  / 255.f}, "orange soda"},
        {{245 / 255.f, 189 / 255.f, 31  / 255.f}, "orange-yellow"},
        {{218 / 255.f, 112 / 255.f, 214 / 255.f}, "orchid"},
        {{242 / 255.f, 189 / 255.f, 205 / 255.f}, "orchid pink"},
        {{251 / 255.f, 79  / 255.f, 20  / 255.f}, "orioles orange"},
        {{101 / 255.f, 67  / 255.f, 33  / 255.f}, "otter brown"},
        {{65  / 255.f, 74  / 255.f, 76  / 255.f}, "outer space"},
        {{255 / 255.f, 110 / 255.f, 74  / 255.f}, "outrageous orange"},
        {{128 / 255.f, 0   / 255.f, 32  / 255.f}, "oxblood"},
        {{0   / 255.f, 33  / 255.f, 71  / 255.f}, "oxford blue"},
        {{109 / 255.f, 154 / 255.f, 121 / 255.f}, "oxley"},
        {{153 / 255.f, 0   / 255.f, 0   / 255.f}, "ou crimson red"},
        {{28  / 255.f, 169 / 255.f, 201 / 255.f}, "pacific blue"},
        {{0   / 255.f, 102 / 255.f, 0   / 255.f}, "pakistan green"},
        {{39  / 255.f, 59  / 255.f, 226 / 255.f}, "palatinate blue"},
        {{104 / 255.f, 40  / 255.f, 96  / 255.f}, "palatinate purple"},
        {{188 / 255.f, 212 / 255.f, 230 / 255.f}, "pale aqua"},
        {{175 / 255.f, 238 / 255.f, 238 / 255.f}, "pale blue"},
        {{152 / 255.f, 118 / 255.f, 84  / 255.f}, "pale brown"},
        {{175 / 255.f, 64  / 255.f, 53  / 255.f}, "pale carmine"},
        {{155 / 255.f, 196 / 255.f, 226 / 255.f}, "pale cerulean"},
        {{221 / 255.f, 173 / 255.f, 175 / 255.f}, "pale chestnut"},
        {{218 / 255.f, 138 / 255.f, 103 / 255.f}, "pale copper"},
        {{171 / 255.f, 205 / 255.f, 239 / 255.f}, "pale cornflower blue"},
        {{135 / 255.f, 211 / 255.f, 248 / 255.f}, "pale cyan"},
        {{230 / 255.f, 190 / 255.f, 138 / 255.f}, "pale gold"},
        {{238 / 255.f, 232 / 255.f, 170 / 255.f}, "pale goldenrod"},
        {{152 / 255.f, 251 / 255.f, 152 / 255.f}, "pale green"},
        {{220 / 255.f, 208 / 255.f, 255 / 255.f}, "pale lavender"},
        {{249 / 255.f, 132 / 255.f, 229 / 255.f}, "pale magenta"},
        {{255 / 255.f, 153 / 255.f, 204 / 255.f}, "pale magenta-pink"},
        {{250 / 255.f, 218 / 255.f, 221 / 255.f}, "pale pink"},
        {{221 / 255.f, 160 / 255.f, 221 / 255.f}, "pale plum"},
        {{219 / 255.f, 112 / 255.f, 147 / 255.f}, "pale red-violet"},
        {{150 / 255.f, 222 / 255.f, 209 / 255.f}, "pale robin egg blue"},
        {{201 / 255.f, 192 / 255.f, 187 / 255.f}, "pale silver"},
        {{236 / 255.f, 235 / 255.f, 189 / 255.f}, "pale spring bud"},
        {{188 / 255.f, 152 / 255.f, 126 / 255.f}, "pale taupe"},
        {{175 / 255.f, 238 / 255.f, 238 / 255.f}, "pale turquoise"},
        {{204 / 255.f, 153 / 255.f, 255 / 255.f}, "pale violet"},
        {{219 / 255.f, 112 / 255.f, 147 / 255.f}, "pale violet-red"},
        {{111 / 255.f, 153 / 255.f, 64  / 255.f}, "palm leaf"},
        {{120 / 255.f, 24  / 255.f, 74  / 255.f}, "pansy purple"},
        {{0   / 255.f, 155 / 255.f, 125 / 255.f}, "paolo veronese green"},
        {{255 / 255.f, 239 / 255.f, 213 / 255.f}, "papaya whip"},
        {{230 / 255.f, 62  / 255.f, 98  / 255.f}, "paradise pink"},
        {{241 / 255.f, 233 / 255.f, 210 / 255.f}, "parchment"},
        {{80  / 255.f, 200 / 255.f, 120 / 255.f}, "paris green"},
        {{217 / 255.f, 152 / 255.f, 160 / 255.f}, "parrot pink"},
        {{174 / 255.f, 198 / 255.f, 207 / 255.f}, "pastel blue"},
        {{130 / 255.f, 105 / 255.f, 83  / 255.f}, "pastel brown"},
        {{207 / 255.f, 207 / 255.f, 196 / 255.f}, "pastel gray"},
        {{119 / 255.f, 221 / 255.f, 119 / 255.f}, "pastel green"},
        {{244 / 255.f, 154 / 255.f, 194 / 255.f}, "pastel magenta"},
        {{255 / 255.f, 179 / 255.f, 71  / 255.f}, "pastel orange"},
        {{222 / 255.f, 165 / 255.f, 164 / 255.f}, "pastel pink"},
        {{179 / 255.f, 158 / 255.f, 181 / 255.f}, "pastel purple"},
        {{255 / 255.f, 105 / 255.f, 97  / 255.f}, "pastel red"},
        {{203 / 255.f, 153 / 255.f, 201 / 255.f}, "pastel violet"},
        {{253 / 255.f, 253 / 255.f, 150 / 255.f}, "pastel yellow"},
        {{128 / 255.f, 0   / 255.f, 128 / 255.f}, "patriarch"},
        {{83  / 255.f, 104 / 255.f, 120 / 255.f}, "payne's grey"},
        {{255 / 255.f, 229 / 255.f, 180 / 255.f}, "peach"},
        {{255 / 255.f, 204 / 255.f, 153 / 255.f}, "peach-orange"},
        {{255 / 255.f, 218 / 255.f, 185 / 255.f}, "peach puff"},
        {{250 / 255.f, 223 / 255.f, 173 / 255.f}, "peach-yellow"},
        {{209 / 255.f, 226 / 255.f, 49  / 255.f}, "pear"},
        {{234 / 255.f, 224 / 255.f, 200 / 255.f}, "pearl"},
        {{136 / 255.f, 216 / 255.f, 192 / 255.f}, "pearl aqua"},
        {{183 / 255.f, 104 / 255.f, 162 / 255.f}, "pearly purple"},
        {{230 / 255.f, 226 / 255.f, 0   / 255.f}, "peridot"},
        {{204 / 255.f, 204 / 255.f, 255 / 255.f}, "periwinkle"},
        {{225 / 255.f, 44  / 255.f, 44  / 255.f}, "permanent geranium lake"},
        {{28  / 255.f, 57  / 255.f, 187 / 255.f}, "persian blue"},
        {{0   / 255.f, 166 / 255.f, 147 / 255.f}, "persian green"},
        {{50  / 255.f, 18  / 255.f, 122 / 255.f}, "persian indigo"},
        {{217 / 255.f, 144 / 255.f, 88  / 255.f}, "persian orange"},
        {{247 / 255.f, 127 / 255.f, 190 / 255.f}, "persian pink"},
        {{112 / 255.f, 28  / 255.f, 28  / 255.f}, "persian plum"},
        {{204 / 255.f, 51  / 255.f, 51  / 255.f}, "persian red"},
        {{254 / 255.f, 40  / 255.f, 162 / 255.f}, "persian rose"},
        {{236 / 255.f, 88  / 255.f, 0   / 255.f}, "persimmon"},
        {{205 / 255.f, 133 / 255.f, 63  / 255.f}, "peru"},
        {{245 / 255.f, 226 / 255.f, 226 / 255.f}, "petal"},
        {{139 / 255.f, 168 / 255.f, 183 / 255.f}, "pewter blue"},
        {{0   / 255.f, 56  / 255.f, 167 / 255.f}, "philippine blue"},
        {{110 / 255.f, 58  / 255.f, 7   / 255.f}, "philippine bronze"},
        {{93  / 255.f, 25  / 255.f, 22  / 255.f}, "philippine brown"},
        {{177 / 255.f, 115 / 255.f, 4   / 255.f}, "philippine gold"},
        {{253 / 255.f, 223 / 255.f, 22  / 255.f}, "philippine golden yellow"},
        {{140 / 255.f, 140 / 255.f, 140 / 255.f}, "philippine gray"},
        {{0   / 255.f, 133 / 255.f, 67  / 255.f}, "philippine green"},
        {{0   / 255.f, 65  / 255.f, 106 / 255.f}, "philippine indigo"},
        {{255 / 255.f, 115 / 255.f, 0   / 255.f}, "philippine orange"},
        {{255 / 255.f, 26  / 255.f, 142 / 255.f}, "philippine pink"},
        {{206 / 255.f, 17  / 255.f, 39  / 255.f}, "philippine red"},
        {{179 / 255.f, 179 / 255.f, 179 / 255.f}, "philippine silver"},
        {{0   / 255.f, 102 / 255.f, 255 / 255.f}, "philippine sky blue"},
        {{129 / 255.f, 0   / 255.f, 127 / 255.f}, "philippine violet"},
        {{254 / 255.f, 203 / 255.f, 0   / 255.f}, "philippine yellow"},
        {{223 / 255.f, 0   / 255.f, 255 / 255.f}, "phlox"},
        {{0   / 255.f, 15  / 255.f, 137 / 255.f}, "phthalo blue"},
        {{18  / 255.f, 53  / 255.f, 36  / 255.f}, "phthalo green"},
        {{69  / 255.f, 177 / 255.f, 232 / 255.f}, "picton blue"},
        {{195 / 255.f, 11  / 255.f, 78  / 255.f}, "pictorial carmine"},
        {{253 / 255.f, 221 / 255.f, 230 / 255.f}, "piggy pink"},
        {{1   / 255.f, 121 / 255.f, 111 / 255.f}, "pine green"},
        {{42  / 255.f, 47  / 255.f, 35  / 255.f}, "pine tree"},
        {{86  / 255.f, 60  / 255.f, 13  / 255.f}, "pineapple"},
        {{255 / 255.f, 192 / 255.f, 203 / 255.f}, "pink"},
        {{240 / 255.f, 211 / 255.f, 220 / 255.f}, "pink diamond"},
        {{252 / 255.f, 116 / 255.f, 253 / 255.f}, "pink flamingo"},
        {{255 / 255.f, 221 / 255.f, 244 / 255.f}, "pink lace"},
        {{216 / 255.f, 178 / 255.f, 209 / 255.f}, "pink lavender"},
        {{255 / 255.f, 153 / 255.f, 102 / 255.f}, "pink-orange"},
        {{231 / 255.f, 172 / 255.f, 207 / 255.f}, "pink pearl"},
        {{152 / 255.f, 0   / 255.f, 54  / 255.f}, "pink raspberry"},
        {{247 / 255.f, 143 / 255.f, 167 / 255.f}, "pink sherbet"},
        {{147 / 255.f, 197 / 255.f, 114 / 255.f}, "pistachio"},
        {{57  / 255.f, 18  / 255.f, 133 / 255.f}, "pixie powder"},
        {{229 / 255.f, 228 / 255.f, 226 / 255.f}, "platinum"},
        {{142 / 255.f, 69  / 255.f, 133 / 255.f}, "plum"},
        {{89  / 255.f, 70  / 255.f, 178 / 255.f}, "plump purple"},
        {{127 / 255.f, 1   / 255.f, 254 / 255.f}, "poison purple"},
        {{55  / 255.f, 79  / 255.f, 107 / 255.f}, "police blue"},
        {{93  / 255.f, 164 / 255.f, 147 / 255.f}, "polished pine"},
        {{134 / 255.f, 96  / 255.f, 142 / 255.f}, "pomp and power"},
        {{190 / 255.f, 79  / 255.f, 98  / 255.f}, "popstar"},
        {{255 / 255.f, 90  / 255.f, 54  / 255.f}, "portland orange"},
        {{176 / 255.f, 224 / 255.f, 230 / 255.f}, "powder blue"},
        {{50  / 255.f, 156 / 255.f, 195 / 255.f}, "prilly blue"},
        {{255 / 255.f, 64  / 255.f, 160 / 255.f}, "prilly pink"},
        {{255 / 255.f, 0   / 255.f, 64  / 255.f}, "prilly red"},
        {{255 / 255.f, 133 / 255.f, 207 / 255.f}, "princess perfume"},
        {{245 / 255.f, 128 / 255.f, 37  / 255.f}, "princeton orange"},
        {{112 / 255.f, 28  / 255.f, 28  / 255.f}, "prune"},
        {{0   / 255.f, 49  / 255.f, 83  / 255.f}, "prussian blue"},
        {{223 / 255.f, 0   / 255.f, 255 / 255.f}, "psychedelic purple"},
        {{204 / 255.f, 136 / 255.f, 153 / 255.f}, "puce"},
        {{114 / 255.f, 47  / 255.f, 55  / 255.f}, "puce red"},
        {{100 / 255.f, 65  / 255.f, 23  / 255.f}, "pullman brown"},
        {{59  / 255.f, 51  / 255.f, 28  / 255.f}, "pullman green"},
        {{255 / 255.f, 117 / 255.f, 24  / 255.f}, "pumpkin"},
        {{159 / 255.f, 0   / 255.f, 197 / 255.f}, "purple"},
        {{105 / 255.f, 53  / 255.f, 156 / 255.f}, "purple heart"},
        {{150 / 255.f, 120 / 255.f, 182 / 255.f}, "purple mountain majesty"},
        {{78  / 255.f, 81  / 255.f, 128 / 255.f}, "purple navy"},
        {{254 / 255.f, 78  / 255.f, 218 / 255.f}, "purple pizzazz"},
        {{156 / 255.f, 81  / 255.f, 182 / 255.f}, "purple plum"},
        {{80  / 255.f, 64  / 255.f, 77  / 255.f}, "purple taupe"},
        {{154 / 255.f, 78  / 255.f, 174 / 255.f}, "purpureus"},
        {{81  / 255.f, 72  / 255.f, 79  / 255.f}, "quartz"},
        {{67  / 255.f, 107 / 255.f, 149 / 255.f}, "queen blue"},
        {{232 / 255.f, 204 / 255.f, 215 / 255.f}, "queen pink"},
        {{166 / 255.f, 166 / 255.f, 166 / 255.f}, "quick silver"},
        {{142 / 255.f, 58  / 255.f, 89  / 255.f}, "quinacridone magenta"},
        {{106 / 255.f, 84  / 255.f, 69  / 255.f}, "quincy"},
        {{93  / 255.f, 138 / 255.f, 168 / 255.f}, "rackley"},
        {{255 / 255.f, 53  / 255.f, 94  / 255.f}, "radical red"},
        {{36  / 255.f, 33  / 255.f, 36  / 255.f}, "raisin black"},
        {{251 / 255.f, 171 / 255.f, 96  / 255.f}, "rajah"},
        {{227 / 255.f, 11  / 255.f, 92  / 255.f}, "raspberry"},
        {{145 / 255.f, 95  / 255.f, 109 / 255.f}, "raspberry glace"},
        {{226 / 255.f, 80  / 255.f, 152 / 255.f}, "raspberry pink"},
        {{179 / 255.f, 68  / 255.f, 108 / 255.f}, "raspberry rose"},
        {{214 / 255.f, 138 / 255.f, 89  / 255.f}, "raw sienna"},
        {{130 / 255.f, 102 / 255.f, 68  / 255.f}, "raw umber"},
        {{255 / 255.f, 51  / 255.f, 204 / 255.f}, "razzle dazzle rose"},
        {{227 / 255.f, 37  / 255.f, 107 / 255.f}, "razzmatazz"},
        {{141 / 255.f, 78  / 255.f, 133 / 255.f}, "razzmic berry"},
        {{102 / 255.f, 52  / 255.f, 153 / 255.f}, "rebecca purple"},
        {{255 / 255.f, 0   / 255.f, 0   / 255.f}, "red"},
        {{165 / 255.f, 42  / 255.f, 42  / 255.f}, "red-brown"},
        {{223 / 255.f, 1   / 255.f, 24  / 255.f}, "red cola"},
        {{134 / 255.f, 1   / 255.f, 17  / 255.f}, "red devil"},
        {{255 / 255.f, 83  / 255.f, 73  / 255.f}, "red-orange"},
        {{228 / 255.f, 0   / 255.f, 120 / 255.f}, "red-purple"},
        {{151 / 255.f, 58  / 255.f, 74  / 255.f}, "red rum"},
        {{253 / 255.f, 58  / 255.f, 74  / 255.f}, "red salsa"},
        {{236 / 255.f, 3   / 255.f, 1   / 255.f}, "red strawberry"},
        {{199 / 255.f, 21  / 255.f, 133 / 255.f}, "red-violet"},
        {{164 / 255.f, 90  / 255.f, 82  / 255.f}, "redwood"},
        {{0   / 255.f, 0   / 255.f, 0   / 255.f}, "registration black"},
        {{0   / 255.f, 35  / 255.f, 135 / 255.f}, "resolution blue"},
        {{119 / 255.f, 118 / 255.f, 150 / 255.f}, "rhythm"},
        {{241 / 255.f, 167 / 255.f, 254 / 255.f}, "rich brilliant lavender"},
        {{215 / 255.f, 0   / 255.f, 64  / 255.f}, "rich carmine"},
        {{8   / 255.f, 146 / 255.f, 208 / 255.f}, "rich electric blue"},
        {{167 / 255.f, 107 / 255.f, 207 / 255.f}, "rich lavender"},
        {{182 / 255.f, 102 / 255.f, 210 / 255.f}, "rich lilac"},
        {{176 / 255.f, 48  / 255.f, 96  / 255.f}, "rich maroon"},
        {{68  / 255.f, 76  / 255.f, 56  / 255.f}, "rifle green"},
        {{255 / 255.f, 195 / 255.f, 36  / 255.f}, "ripe mango"},
        {{112 / 255.f, 66  / 255.f, 65  / 255.f}, "roast coffee"},
        {{0   / 255.f, 204 / 255.f, 204 / 255.f}, "robin egg blue"},
        {{138 / 255.f, 127 / 255.f, 128 / 255.f}, "rocket metallic"},
        {{131 / 255.f, 137 / 255.f, 150 / 255.f}, "roman silver"},
        {{41  / 255.f, 14  / 255.f, 5   / 255.f}, "root beer"},
        {{255 / 255.f, 0   / 255.f, 127 / 255.f}, "rose"},
        {{249 / 255.f, 66  / 255.f, 158 / 255.f}, "rose bonbon"},
        {{158 / 255.f, 94  / 255.f, 111 / 255.f}, "rose dust"},
        {{103 / 255.f, 72  / 255.f, 70  / 255.f}, "rose ebony"},
        {{150 / 255.f, 1   / 255.f, 69  / 255.f}, "rose garnet"},
        {{183 / 255.f, 110 / 255.f, 121 / 255.f}, "rose gold"},
        {{227 / 255.f, 38  / 255.f, 54  / 255.f}, "rose madder"},
        {{255 / 255.f, 102 / 255.f, 204 / 255.f}, "rose pink"},
        {{170 / 255.f, 152 / 255.f, 169 / 255.f}, "rose quartz"},
        {{189 / 255.f, 85  / 255.f, 156 / 255.f}, "rose quartz pink"},
        {{194 / 255.f, 30  / 255.f, 86  / 255.f}, "rose red"},
        {{144 / 255.f, 93  / 255.f, 93  / 255.f}, "rose taupe"},
        {{171 / 255.f, 78  / 255.f, 82  / 255.f}, "rose vale"},
        {{101 / 255.f, 0   / 255.f, 11  / 255.f}, "rosewood"},
        {{188 / 255.f, 143 / 255.f, 143 / 255.f}, "rosy brown"},
        {{0   / 255.f, 56  / 255.f, 168 / 255.f}, "royal azure"},
        {{0   / 255.f, 35  / 255.f, 102 / 255.f}, "royal blue"},
        {{65  / 255.f, 105 / 255.f, 225 / 255.f}, "royal blue"},
        {{82  / 255.f, 59  / 255.f, 53  / 255.f}, "royal brown"},
        {{202 / 255.f, 44  / 255.f, 146 / 255.f}, "royal fuchsia"},
        {{19  / 255.f, 98  / 255.f, 7   / 255.f}, "royal green"},
        {{249 / 255.f, 146 / 255.f, 69  / 255.f}, "royal orange"},
        {{231 / 255.f, 56  / 255.f, 149 / 255.f}, "royal pink"},
        {{155 / 255.f, 28  / 255.f, 49  / 255.f}, "royal red"},
        {{208 / 255.f, 0   / 255.f, 96  / 255.f}, "royal red"},
        {{120 / 255.f, 81  / 255.f, 169 / 255.f}, "royal purple"},
        {{250 / 255.f, 218 / 255.f, 94  / 255.f}, "royal yellow"},
        {{206 / 255.f, 70  / 255.f, 118 / 255.f}, "ruber"},
        {{209 / 255.f, 0   / 255.f, 86  / 255.f}, "rubine red"},
        {{224 / 255.f, 17  / 255.f, 95  / 255.f}, "ruby"},
        {{155 / 255.f, 17  / 255.f, 30  / 255.f}, "ruby red"},
        {{168 / 255.f, 28  / 255.f, 7   / 255.f}, "rufous"},
        {{154 / 255.f, 78  / 255.f, 64  / 255.f}, "rum"},
        {{128 / 255.f, 70  / 255.f, 27  / 255.f}, "russet"},
        {{103 / 255.f, 146 / 255.f, 103 / 255.f}, "russian green"},
        {{50  / 255.f, 23  / 255.f, 77  / 255.f}, "russian violet"},
        {{183 / 255.f, 65  / 255.f, 14  / 255.f}, "rust"},
        {{218 / 255.f, 44  / 255.f, 67  / 255.f}, "rusty red"},
        {{4   / 255.f, 57  / 255.f, 39  / 255.f}, "sacramento state green"},
        {{139 / 255.f, 69  / 255.f, 19  / 255.f}, "saddle brown"},
        {{255 / 255.f, 120 / 255.f, 0   / 255.f}, "safety orange"},
        {{238 / 255.f, 210 / 255.f, 2   / 255.f}, "safety yellow"},
        {{244 / 255.f, 196 / 255.f, 48  / 255.f}, "saffron"},
        {{188 / 255.f, 184 / 255.f, 138 / 255.f}, "sage"},
        {{35  / 255.f, 41  / 255.f, 122 / 255.f}, "st. patrick's blue"},
        {{23  / 255.f, 123 / 255.f, 77  / 255.f}, "salem"},
        {{250 / 255.f, 128 / 255.f, 114 / 255.f}, "salmon"},
        {{231 / 255.f, 150 / 255.f, 139 / 255.f}, "salmon rose"},
        {{255 / 255.f, 145 / 255.f, 164 / 255.f}, "salmon pink"},
        {{18  / 255.f, 39  / 255.f, 158 / 255.f}, "samsung blue"},
        {{194 / 255.f, 178 / 255.f, 128 / 255.f}, "sand"},
        {{150 / 255.f, 113 / 255.f, 23  / 255.f}, "sand dune"},
        {{236 / 255.f, 213 / 255.f, 64  / 255.f}, "sandstorm"},
        {{244 / 255.f, 164 / 255.f, 96  / 255.f}, "sandy brown"},
        {{253 / 255.f, 217 / 255.f, 181 / 255.f}, "sandy tan"},
        {{150 / 255.f, 113 / 255.f, 23  / 255.f}, "sandy taupe"},
        {{80  / 255.f, 125 / 255.f, 42  / 255.f}, "sap green"},
        {{15  / 255.f, 82  / 255.f, 186 / 255.f}, "sapphire"},
        {{0   / 255.f, 103 / 255.f, 165 / 255.f}, "sapphire blue"},
        {{255 / 255.f, 70  / 255.f, 129 / 255.f}, "sasquatch socks"},
        {{203 / 255.f, 161 / 255.f, 53  / 255.f}, "satin sheen gold"},
        {{255 / 255.f, 36  / 255.f, 0   / 255.f}, "scarlet"},
        {{255 / 255.f, 145 / 255.f, 175 / 255.f}, "schauss pink"},
        {{255 / 255.f, 216 / 255.f, 0   / 255.f}, "school bus yellow"},
        {{102 / 255.f, 255 / 255.f, 102 / 255.f}, "screamin' green"},
        {{0   / 255.f, 105 / 255.f, 148 / 255.f}, "sea blue"},
        {{195 / 255.f, 226 / 255.f, 191 / 255.f}, "sea foam green"},
        {{46  / 255.f, 139 / 255.f, 87  / 255.f}, "sea green"},
        {{75  / 255.f, 199 / 255.f, 207 / 255.f}, "sea serpent"},
        {{50  / 255.f, 20  / 255.f, 20  / 255.f}, "seal brown"},
        {{255 / 255.f, 245 / 255.f, 238 / 255.f}, "seashell"},
        {{255 / 255.f, 186 / 255.f, 0   / 255.f}, "selective yellow"},
        {{112 / 255.f, 66  / 255.f, 20  / 255.f}, "sepia"},
        {{138 / 255.f, 121 / 255.f, 93  / 255.f}, "shadow"},
        {{119 / 255.f, 139 / 255.f, 165 / 255.f}, "shadow blue"},
        {{255 / 255.f, 207 / 255.f, 241 / 255.f}, "shampoo"},
        {{0   / 255.f, 158 / 255.f, 96  / 255.f}, "shamrock green"},
        {{255 / 255.f, 230 / 255.f, 112 / 255.f}, "shandy"},
        {{143 / 255.f, 212 / 255.f, 0   / 255.f}, "sheen green"},
        {{217 / 255.f, 134 / 255.f, 149 / 255.f}, "shimmering blush"},
        {{95  / 255.f, 167 / 255.f, 120 / 255.f}, "shiny shamrock"},
        {{252 / 255.f, 15  / 255.f, 192 / 255.f}, "shocking pink"},
        {{136 / 255.f, 45  / 255.f, 23  / 255.f}, "sienna"},
        {{192 / 255.f, 192 / 255.f, 192 / 255.f}, "silver"},
        {{172 / 255.f, 172 / 255.f, 172 / 255.f}, "silver chalice"},
        {{175 / 255.f, 177 / 255.f, 174 / 255.f}, "silver foil"},
        {{93  / 255.f, 137 / 255.f, 186 / 255.f}, "silver lake blue"},
        {{196 / 255.f, 174 / 255.f, 173 / 255.f}, "silver pink"},
        {{191 / 255.f, 193 / 255.f, 194 / 255.f}, "silver sand"},
        {{203 / 255.f, 65  / 255.f, 11  / 255.f}, "sinopia"},
        {{255 / 255.f, 56  / 255.f, 85  / 255.f}, "sizzling red"},
        {{255 / 255.f, 219 / 255.f, 0   / 255.f}, "sizzling sunrise"},
        {{0   / 255.f, 116 / 255.f, 116 / 255.f}, "skobeloff"},
        {{135 / 255.f, 206 / 255.f, 235 / 255.f}, "sky blue"},
        {{207 / 255.f, 113 / 255.f, 175 / 255.f}, "sky magenta"},
        {{106 / 255.f, 90  / 255.f, 205 / 255.f}, "slate blue"},
        {{112 / 255.f, 128 / 255.f, 144 / 255.f}, "slate gray"},
        {{41  / 255.f, 150 / 255.f, 23  / 255.f}, "slimy green"},
        {{0   / 255.f, 51  / 255.f, 153 / 255.f}, "smalt"},
        {{255 / 255.f, 109 / 255.f, 58  / 255.f}, "smashed pumpkin"},
        {{200 / 255.f, 65  / 255.f, 134 / 255.f}, "smitten"},
        {{115 / 255.f, 130 / 255.f, 118 / 255.f}, "smoke"},
        {{131 / 255.f, 42  / 255.f, 34  / 255.f}, "smokey topaz"},
        {{16  / 255.f, 12  / 255.f, 8   / 255.f}, "smoky black"},
        {{255 / 255.f, 250 / 255.f, 250 / 255.f}, "snow"},
        {{206 / 255.f, 200 / 255.f, 239 / 255.f}, "soap"},
        {{137 / 255.f, 56  / 255.f, 67  / 255.f}, "solid pink"},
        {{117 / 255.f, 117 / 255.f, 117 / 255.f}, "sonic silver"},
        {{158 / 255.f, 19  / 255.f, 22  / 255.f}, "spartan crimson"},
        {{29  / 255.f, 41  / 255.f, 81  / 255.f}, "space cadet"},
        {{128 / 255.f, 117 / 255.f, 50  / 255.f}, "spanish bistre"},
        {{0   / 255.f, 112 / 255.f, 184 / 255.f}, "spanish blue"},
        {{209 / 255.f, 0   / 255.f, 71  / 255.f}, "spanish carmine"},
        {{229 / 255.f, 26  / 255.f, 76  / 255.f}, "spanish crimson"},
        {{152 / 255.f, 152 / 255.f, 152 / 255.f}, "spanish gray"},
        {{0   / 255.f, 145 / 255.f, 80  / 255.f}, "spanish green"},
        {{232 / 255.f, 97  / 255.f, 0   / 255.f}, "spanish orange"},
        {{247 / 255.f, 191 / 255.f, 190 / 255.f}, "spanish pink"},
        {{102 / 255.f, 3   / 255.f, 60  / 255.f}, "spanish purple"},
        {{230 / 255.f, 0   / 255.f, 38  / 255.f}, "spanish red"},
        {{0   / 255.f, 255 / 255.f, 255 / 255.f}, "spanish sky blue"},
        {{76  / 255.f, 40  / 255.f, 130 / 255.f}, "spanish violet"},
        {{0   / 255.f, 127 / 255.f, 92  / 255.f}, "spanish viridian"},
        {{246 / 255.f, 181 / 255.f, 17  / 255.f}, "spanish yellow"},
        {{139 / 255.f, 95  / 255.f, 77  / 255.f}, "spicy mix"},
        {{15  / 255.f, 192 / 255.f, 252 / 255.f}, "spiro disco ball"},
        {{167 / 255.f, 252 / 255.f, 0   / 255.f}, "spring bud"},
        {{135 / 255.f, 255 / 255.f, 42  / 255.f}, "spring frost"},
        {{0   / 255.f, 255 / 255.f, 127 / 255.f}, "spring green"},
        {{236 / 255.f, 235 / 255.f, 189 / 255.f}, "spring green"},
        {{0   / 255.f, 123 / 255.f, 184 / 255.f}, "star command blue"},
        {{70  / 255.f, 130 / 255.f, 180 / 255.f}, "steel blue"},
        {{204 / 255.f, 51  / 255.f, 204 / 255.f}, "steel pink"},
        {{95  / 255.f, 138 / 255.f, 139 / 255.f}, "steel teal"},
        {{250 / 255.f, 218 / 255.f, 94  / 255.f}, "stil de grain yellow"},
        {{228 / 255.f, 217 / 255.f, 111 / 255.f}, "straw"},
        {{252 / 255.f, 90  / 255.f, 141 / 255.f}, "strawberry"},
        {{207 / 255.f, 20  / 255.f, 43  / 255.f}, "stop red"},
        {{252 / 255.f, 90  / 255.f, 141 / 255.f}, "strawberry iced tea"},
        {{200 / 255.f, 63  / 255.f, 73  / 255.f}, "strawberry red"},
        {{145 / 255.f, 78  / 255.f, 117 / 255.f}, "sugar plum"},
        {{255 / 255.f, 64  / 255.f, 76  / 255.f}, "sunburnt cyclops"},
        {{255 / 255.f, 204 / 255.f, 51  / 255.f}, "sunglow"},
        {{242 / 255.f, 242 / 255.f, 122 / 255.f}, "sunny"},
        {{227 / 255.f, 171 / 255.f, 87  / 255.f}, "sunray"},
        {{250 / 255.f, 214 / 255.f, 165 / 255.f}, "sunset"},
        {{253 / 255.f, 94  / 255.f, 83  / 255.f}, "sunset orange"},
        {{207 / 255.f, 107 / 255.f, 169 / 255.f}, "super pink"},
        {{168 / 255.f, 55  / 255.f, 49  / 255.f}, "sweet brown"},
        {{254 / 255.f, 166 / 255.f, 200 / 255.f}, "taffy"},
        {{210 / 255.f, 180 / 255.f, 140 / 255.f}, "tan"},
        {{249 / 255.f, 77  / 255.f, 0   / 255.f}, "tangelo"},
        {{242 / 255.f, 133 / 255.f, 0   / 255.f}, "tangerine"},
        {{255 / 255.f, 204 / 255.f, 0   / 255.f}, "tangerine yellow"},
        {{228 / 255.f, 113 / 255.f, 122 / 255.f}, "tango pink"},
        {{251 / 255.f, 77  / 255.f, 70  / 255.f}, "tart orange"},
        {{72  / 255.f, 60  / 255.f, 50  / 255.f}, "taupe"},
        {{139 / 255.f, 133 / 255.f, 137 / 255.f}, "taupe gray"},
        {{208 / 255.f, 240 / 255.f, 192 / 255.f}, "tea green"},
        {{248 / 255.f, 131 / 255.f, 121 / 255.f}, "tea rose"},
        {{244 / 255.f, 194 / 255.f, 194 / 255.f}, "tea rose"},
        {{0   / 255.f, 128 / 255.f, 128 / 255.f}, "teal"},
        {{54  / 255.f, 117 / 255.f, 136 / 255.f}, "teal blue"},
        {{153 / 255.f, 230 / 255.f, 179 / 255.f}, "teal deer"},
        {{0   / 255.f, 130 / 255.f, 127 / 255.f}, "teal green"},
        {{207 / 255.f, 52  / 255.f, 118 / 255.f}, "telemagenta"},
        {{60  / 255.f, 33  / 255.f, 38  / 255.f}, "temptress"},
        {{205 / 255.f, 87  / 255.f, 0   / 255.f}, "tenné"},
        {{226 / 255.f, 114 / 255.f, 91  / 255.f}, "terra cotta"},
        {{216 / 255.f, 191 / 255.f, 216 / 255.f}, "thistle"},
        {{222 / 255.f, 111 / 255.f, 161 / 255.f}, "thulian pink"},
        {{252 / 255.f, 137 / 255.f, 172 / 255.f}, "tickle me pink"},
        {{129 / 255.f, 216 / 255.f, 208 / 255.f}, "tiffany blue"},
        {{224 / 255.f, 141 / 255.f, 60  / 255.f}, "tiger's eye"},
        {{219 / 255.f, 215 / 255.f, 210 / 255.f}, "timberwolf"},
        {{135 / 255.f, 134 / 255.f, 129 / 255.f}, "titanium"},
        {{238 / 255.f, 230 / 255.f, 0   / 255.f}, "titanium yellow"},
        {{255 / 255.f, 99  / 255.f, 71  / 255.f}, "tomato"},
        {{178 / 255.f, 24  / 255.f, 7   / 255.f}, "tomato sauce"},
        {{116 / 255.f, 108 / 255.f, 192 / 255.f}, "toolbox"},
        {{255 / 255.f, 250 / 255.f, 250 / 255.f}, "tooth"},
        {{255 / 255.f, 200 / 255.f, 124 / 255.f}, "topaz"},
        {{253 / 255.f, 14  / 255.f, 53  / 255.f}, "tractor red"},
        {{128 / 255.f, 128 / 255.f, 128 / 255.f}, "trolley grey"},
        {{0   / 255.f, 117 / 255.f, 94  / 255.f}, "tropical rain forest"},
        {{205 / 255.f, 164 / 255.f, 222 / 255.f}, "tropical violet"},
        {{0   / 255.f, 115 / 255.f, 207 / 255.f}, "true blue"},
        {{62  / 255.f, 142 / 255.f, 222 / 255.f}, "tufts blue"},
        {{255 / 255.f, 135 / 255.f, 141 / 255.f}, "tulip"},
        {{222 / 255.f, 170 / 255.f, 136 / 255.f}, "tumbleweed"},
        {{181 / 255.f, 114 / 255.f, 129 / 255.f}, "turkish rose"},
        {{64  / 255.f, 224 / 255.f, 208 / 255.f}, "turquoise"},
        {{0   / 255.f, 255 / 255.f, 239 / 255.f}, "turquoise blue"},
        {{160 / 255.f, 214 / 255.f, 180 / 255.f}, "turquoise green"},
        {{0   / 255.f, 197 / 255.f, 205 / 255.f}, "turquoise surf"},
        {{138 / 255.f, 154 / 255.f, 91  / 255.f}, "turtle green"},
        {{250 / 255.f, 214 / 255.f, 165 / 255.f}, "tuscan"},
        {{111 / 255.f, 78  / 255.f, 55  / 255.f}, "tuscan brown"},
        {{124 / 255.f, 72  / 255.f, 72  / 255.f}, "tuscan red"},
        {{166 / 255.f, 123 / 255.f, 91  / 255.f}, "tuscan tan"},
        {{192 / 255.f, 153 / 255.f, 153 / 255.f}, "tuscany"},
        {{138 / 255.f, 73  / 255.f, 107 / 255.f}, "twilight lavender"},
        {{38  / 255.f, 167 / 255.f, 222 / 255.f}, "twitter blue"},
        {{102 / 255.f, 2   / 255.f, 60  / 255.f}, "tyrian purple"},
        {{136 / 255.f, 120 / 255.f, 195 / 255.f}, "ube"},
        {{18  / 255.f, 10  / 255.f, 143 / 255.f}, "ultramarine"},
        {{65  / 255.f, 102 / 255.f, 245 / 255.f}, "ultramarine blue"},
        {{255 / 255.f, 111 / 255.f, 255 / 255.f}, "ultra pink"},
        {{252 / 255.f, 108 / 255.f, 133 / 255.f}, "ultra red"},
        {{99  / 255.f, 81  / 255.f, 71  / 255.f}, "umber"},
        {{255 / 255.f, 221 / 255.f, 202 / 255.f}, "unbleached silk"},
        {{91  / 255.f, 146 / 255.f, 229 / 255.f}, "united nations blue"},
        {{255 / 255.f, 255 / 255.f, 102 / 255.f}, "unmellow yellow"},
        {{123 / 255.f, 17  / 255.f, 19  / 255.f}, "up maroon"},
        {{174 / 255.f, 32  / 255.f, 41  / 255.f}, "upsdell red"},
        {{225 / 255.f, 173 / 255.f, 33  / 255.f}, "urobilin"},
        {{8   / 255.f, 8   / 255.f, 8   / 255.f}, "vampire black"},
        {{102 / 255.f, 66  / 255.f, 40  / 255.f}, "van dyke brown"},
        {{243 / 255.f, 229 / 255.f, 171 / 255.f}, "vanilla"},
        {{243 / 255.f, 143 / 255.f, 169 / 255.f}, "vanilla ice"},
        {{197 / 255.f, 179 / 255.f, 88  / 255.f}, "vegas gold"},
        {{200 / 255.f, 8   / 255.f, 21  / 255.f}, "venetian red"},
        {{67  / 255.f, 179 / 255.f, 174 / 255.f}, "verdigris"},
        {{227 / 255.f, 66  / 255.f, 52  / 255.f}, "vermilion"},
        {{217 / 255.f, 56  / 255.f, 30  / 255.f}, "vermilion"},
        {{160 / 255.f, 32  / 255.f, 240 / 255.f}, "veronica"},
        {{24  / 255.f, 136 / 255.f, 13  / 255.f}, "verse green"},
        {{116 / 255.f, 187 / 255.f, 251 / 255.f}, "very light azure"},
        {{102 / 255.f, 102 / 255.f, 255 / 255.f}, "very light blue"},
        {{100 / 255.f, 233 / 255.f, 134 / 255.f}, "very light malachite green"},
        {{255 / 255.f, 176 / 255.f, 119 / 255.f}, "very light tangelo"},
        {{255 / 255.f, 223 / 255.f, 191 / 255.f}, "very pale orange"},
        {{255 / 255.f, 255 / 255.f, 191 / 255.f}, "very pale yellow"},
        {{22  / 255.f, 64  / 255.f, 16  / 255.f}, "vine green"},
        {{143 / 255.f, 0   / 255.f, 255 / 255.f}, "violet"},
        {{50  / 255.f, 74  / 255.f, 178 / 255.f}, "violet-blue"},
        {{247 / 255.f, 83  / 255.f, 148 / 255.f}, "violet-red"},
        {{103 / 255.f, 68  / 255.f, 3   / 255.f}, "violin brown"},
        {{64  / 255.f, 130 / 255.f, 109 / 255.f}, "viridian"},
        {{0   / 255.f, 150 / 255.f, 152 / 255.f}, "viridian green"},
        {{124 / 255.f, 158 / 255.f, 217 / 255.f}, "vista blue"},
        {{204 / 255.f, 153 / 255.f, 0   / 255.f}, "vivid amber"},
        {{146 / 255.f, 39  / 255.f, 36  / 255.f}, "vivid auburn"},
        {{159 / 255.f, 29  / 255.f, 53  / 255.f}, "vivid burgundy"},
        {{218 / 255.f, 29  / 255.f, 129 / 255.f}, "vivid cerise"},
        {{0   / 255.f, 170 / 255.f, 238 / 255.f}, "vivid cerulean"},
        {{204 / 255.f, 0   / 255.f, 51  / 255.f}, "vivid crimson"},
        {{255 / 255.f, 153 / 255.f, 0   / 255.f}, "vivid gamboge"},
        {{166 / 255.f, 214 / 255.f, 8   / 255.f}, "vivid lime green"},
        {{0   / 255.f, 204 / 255.f, 51  / 255.f}, "vivid malachite"},
        {{184 / 255.f, 12  / 255.f, 227 / 255.f}, "vivid mulberry"},
        {{255 / 255.f, 95  / 255.f, 0   / 255.f}, "vivid orange"},
        {{255 / 255.f, 160 / 255.f, 0   / 255.f}, "vivid orange peel"},
        {{204 / 255.f, 0   / 255.f, 255 / 255.f}, "vivid orchid"},
        {{255 / 255.f, 0   / 255.f, 108 / 255.f}, "vivid raspberry"},
        {{247 / 255.f, 13  / 255.f, 26  / 255.f}, "vivid red"},
        {{223 / 255.f, 97  / 255.f, 36  / 255.f}, "vivid red-tangelo"},
        {{0   / 255.f, 204 / 255.f, 255 / 255.f}, "vivid skye blue"},
        {{240 / 255.f, 116 / 255.f, 39  / 255.f}, "vivid tangelo"},
        {{255 / 255.f, 160 / 255.f, 137 / 255.f}, "vivid tangerine"},
        {{229 / 255.f, 96  / 255.f, 36  / 255.f}, "vivid vermilion"},
        {{159 / 255.f, 0   / 255.f, 255 / 255.f}, "vivid violet"},
        {{255 / 255.f, 227 / 255.f, 2   / 255.f}, "vivid yellow"},
        {{212 / 255.f, 241 / 255.f, 249 / 255.f}, "water"},
        {{240 / 255.f, 92  / 255.f, 133 / 255.f}, "watermelon"},
        {{190 / 255.f, 65  / 255.f, 71  / 255.f}, "watermelon red"},
        {{238 / 255.f, 255 / 255.f, 27  / 255.f}, "watermelon yellow"},
        {{164 / 255.f, 244 / 255.f, 249 / 255.f}, "waterspout"},
        {{124 / 255.f, 152 / 255.f, 171 / 255.f}, "weldon blue"},
        {{100 / 255.f, 84  / 255.f, 82  / 255.f}, "wenge"},
        {{245 / 255.f, 222 / 255.f, 179 / 255.f}, "wheat"},
        {{255 / 255.f, 255 / 255.f, 255 / 255.f}, "white"},
        {{237 / 255.f, 230 / 255.f, 214 / 255.f}, "white chocolate"},
        {{230 / 255.f, 224 / 255.f, 212 / 255.f}, "white coffee"},
        {{245 / 255.f, 245 / 255.f, 245 / 255.f}, "white smoke"},
        {{212 / 255.f, 112 / 255.f, 162 / 255.f}, "wild orchid"},
        {{255 / 255.f, 67  / 255.f, 164 / 255.f}, "wild strawberry"},
        {{252 / 255.f, 108 / 255.f, 133 / 255.f}, "wild watermelon"},
        {{253 / 255.f, 88  / 255.f, 0   / 255.f}, "willpower orange"},
        {{167 / 255.f, 85  / 255.f, 2   / 255.f}, "windsor tan"},
        {{114 / 255.f, 47  / 255.f, 55  / 255.f}, "wine"},
        {{103 / 255.f, 49  / 255.f, 71  / 255.f}, "wine dregs"},
        {{177 / 255.f, 18  / 255.f, 38  / 255.f}, "wine red"},
        {{255 / 255.f, 0   / 255.f, 124 / 255.f}, "winter sky"},
        {{160 / 255.f, 230 / 255.f, 255 / 255.f}, "winter wizard"},
        {{86  / 255.f, 136 / 255.f, 125 / 255.f}, "wintergreen dream"},
        {{201 / 255.f, 160 / 255.f, 220 / 255.f}, "wisteria"},
        {{193 / 255.f, 154 / 255.f, 107 / 255.f}, "wood brown"},
        {{115 / 255.f, 134 / 255.f, 120 / 255.f}, "xanadu"},
        {{255 / 255.f, 255 / 255.f, 0   / 255.f}, "yellow"},
        {{154 / 255.f, 205 / 255.f, 50  / 255.f}, "yellow-green"},
        {{255 / 255.f, 174 / 255.f, 66  / 255.f}, "yellow orange"},
        {{255 / 255.f, 240 / 255.f, 0   / 255.f}, "yellow rose"},
        {{255 / 255.f, 247 / 255.f, 0   / 255.f}, "yellow sunshine"},
        {{46  / 255.f, 80  / 255.f, 144 / 255.f}, "yinmn blue"},
        {{0   / 255.f, 20  / 255.f, 168 / 255.f}, "zaffre"},
        {{245 / 255.f, 245 / 255.f, 245 / 255.f}, "zebra white"},
        {{44  / 255.f, 22  / 255.f, 8   / 255.f}, "zinnwaldite"},
        {{57  / 255.f, 167 / 255.f, 142 / 255.f}, "zomp"},
    };

} // Generators


#endif // LINKRBRAIN2019__SRC__GENERATORS__COLORNAME_HPP
